# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.core.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.api import resource_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_api_dot_resource__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.util import intstr_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_util_dot_intstr__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.kubernetes/kubernetes_io.k8s.api.core.v1.proto\x12\x1boak9.tython.k8s.api.core.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.api.resource.proto\x1a?kubernetes/kubernetes_io.k8s.apimachinery.pkg.util.intstr.proto\"\xa5\x01\n AWSElasticBlockStoreVolumeSource\x12\x0f\n\x07\x66s_type\x18\x01 \x01(\t\x12\x11\n\tpartition\x18\x02 \x01(\x05\x12\x11\n\tread_only\x18\x03 \x01(\x08\x12\x11\n\tvolume_id\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8e\x02\n\x08\x41\x66\x66inity\x12@\n\rnode_affinity\x18\x01 \x01(\x0b\x32).oak9.tython.k8s.api.core.v1.NodeAffinity\x12>\n\x0cpod_affinity\x18\x02 \x01(\x0b\x32(.oak9.tython.k8s.api.core.v1.PodAffinity\x12G\n\x11pod_anti_affinity\x18\x03 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.PodAntiAffinity\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"l\n\x0e\x41ttachedVolume\x12\x13\n\x0b\x64\x65vice_path\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbf\x01\n\x15\x41zureDiskVolumeSource\x12\x14\n\x0c\x63\x61\x63hing_mode\x18\x01 \x01(\t\x12\x11\n\tdisk_name\x18\x02 \x01(\t\x12\x12\n\ndisk_u_r_i\x18\x03 \x01(\t\x12\x0f\n\x07\x66s_type\x18\x04 \x01(\t\x12\x0c\n\x04kind\x18\x05 \x01(\t\x12\x11\n\tread_only\x18\x06 \x01(\x08\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb0\x01\n\x1f\x41zureFilePersistentVolumeSource\x12\x11\n\tread_only\x18\x01 \x01(\x08\x12\x13\n\x0bsecret_name\x18\x02 \x01(\t\x12\x18\n\x10secret_namespace\x18\x03 \x01(\t\x12\x12\n\nshare_name\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8c\x01\n\x15\x41zureFileVolumeSource\x12\x11\n\tread_only\x18\x01 \x01(\x08\x12\x13\n\x0bsecret_name\x18\x02 \x01(\t\x12\x12\n\nshare_name\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf0\x01\n\x07\x42inding\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12<\n\x06target\x18\x04 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.ObjectReference\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd4\x05\n\x19\x43SIPersistentVolumeSource\x12R\n\x1c\x63ontroller_expand_secret_ref\x18\x01 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.SecretReference\x12S\n\x1d\x63ontroller_publish_secret_ref\x18\x02 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.SecretReference\x12\x0e\n\x06\x64river\x18\x03 \x01(\t\x12\x0f\n\x07\x66s_type\x18\x04 \x01(\t\x12L\n\x16node_expand_secret_ref\x18\x05 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.SecretReference\x12M\n\x17node_publish_secret_ref\x18\x06 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.SecretReference\x12K\n\x15node_stage_secret_ref\x18\x07 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.SecretReference\x12\x11\n\tread_only\x18\x08 \x01(\x08\x12g\n\x11volume_attributes\x18\t \x03(\x0b\x32L.oak9.tython.k8s.api.core.v1.CSIPersistentVolumeSource.VolumeAttributesEntry\x12\x15\n\rvolume_handle\x18\n \x01(\t\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x37\n\x15VolumeAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xea\x02\n\x0f\x43SIVolumeSource\x12\x0e\n\x06\x64river\x18\x01 \x01(\t\x12\x0f\n\x07\x66s_type\x18\x02 \x01(\t\x12R\n\x17node_publish_secret_ref\x18\x03 \x01(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.LocalObjectReference\x12\x11\n\tread_only\x18\x04 \x01(\x08\x12]\n\x11volume_attributes\x18\x05 \x03(\x0b\x32\x42.oak9.tython.k8s.api.core.v1.CSIVolumeSource.VolumeAttributesEntry\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x37\n\x15VolumeAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\n\x0c\x43\x61pabilities\x12\x0b\n\x03\x61\x64\x64\x18\x01 \x03(\t\x12\x0c\n\x04\x64rop\x18\x02 \x03(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xef\x01\n\x1c\x43\x65phFSPersistentVolumeSource\x12\x10\n\x08monitors\x18\x01 \x03(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x11\n\tread_only\x18\x03 \x01(\x08\x12\x13\n\x0bsecret_file\x18\x04 \x01(\t\x12@\n\nsecret_ref\x18\x05 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.SecretReference\x12\x0c\n\x04user\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xea\x01\n\x12\x43\x65phFSVolumeSource\x12\x10\n\x08monitors\x18\x01 \x03(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x11\n\tread_only\x18\x03 \x01(\x08\x12\x13\n\x0bsecret_file\x18\x04 \x01(\t\x12\x45\n\nsecret_ref\x18\x05 \x01(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.LocalObjectReference\x12\x0c\n\x04user\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd0\x01\n\x1c\x43inderPersistentVolumeSource\x12\x0f\n\x07\x66s_type\x18\x01 \x01(\t\x12\x11\n\tread_only\x18\x02 \x01(\x08\x12@\n\nsecret_ref\x18\x03 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.SecretReference\x12\x11\n\tvolume_id\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xcb\x01\n\x12\x43inderVolumeSource\x12\x0f\n\x07\x66s_type\x18\x01 \x01(\t\x12\x11\n\tread_only\x18\x02 \x01(\x08\x12\x45\n\nsecret_ref\x18\x03 \x01(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.LocalObjectReference\x12\x11\n\tvolume_id\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x89\x01\n\x0b\x43laimSource\x12\x1b\n\x13resource_claim_name\x18\x01 \x01(\t\x12$\n\x1cresource_claim_template_name\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"b\n\x0e\x43lientIPConfig\x12\x17\n\x0ftimeout_seconds\x18\x01 \x01(\x05\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8b\x01\n\x12\x43omponentCondition\x12\r\n\x05\x65rror\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xff\x01\n\x0f\x43omponentStatus\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x43\n\nconditions\x18\x02 \x03(\x0b\x32/.oak9.tython.k8s.api.core.v1.ComponentCondition\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12K\n\x08metadata\x18\x04 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf9\x01\n\x13\x43omponentStatusList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12;\n\x05items\x18\x02 \x03(\x0b\x32,.oak9.tython.k8s.api.core.v1.ComponentStatus\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb4\x03\n\tConfigMap\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12K\n\x0b\x62inary_data\x18\x02 \x03(\x0b\x32\x36.oak9.tython.k8s.api.core.v1.ConfigMap.BinaryDataEntry\x12>\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x30.oak9.tython.k8s.api.core.v1.ConfigMap.DataEntry\x12\x11\n\timmutable\x18\x04 \x01(\x08\x12\x0c\n\x04kind\x18\x05 \x01(\t\x12K\n\x08metadata\x18\x06 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x31\n\x0f\x42inaryDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"m\n\x12\x43onfigMapEnvSource\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08optional\x18\x02 \x01(\x08\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"|\n\x14\x43onfigMapKeySelector\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08optional\x18\x03 \x01(\x08\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xed\x01\n\rConfigMapList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x35\n\x05items\x18\x02 \x03(\x0b\x32&.oak9.tython.k8s.api.core.v1.ConfigMap\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb8\x01\n\x19\x43onfigMapNodeConfigSource\x12\x1a\n\x12kubelet_config_key\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x18\n\x10resource_version\x18\x04 \x01(\t\x12\x0b\n\x03uid\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa5\x01\n\x13\x43onfigMapProjection\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32&.oak9.tython.k8s.api.core.v1.KeyToPath\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08optional\x18\x03 \x01(\x08\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbd\x01\n\x15\x43onfigMapVolumeSource\x12\x14\n\x0c\x64\x65\x66\x61ult_mode\x18\x01 \x01(\x05\x12\x35\n\x05items\x18\x02 \x03(\x0b\x32&.oak9.tython.k8s.api.core.v1.KeyToPath\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08optional\x18\x04 \x01(\x08\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd2\x07\n\tContainer\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x03(\t\x12\x30\n\x03\x65nv\x18\x03 \x03(\x0b\x32#.oak9.tython.k8s.api.core.v1.EnvVar\x12<\n\x08\x65nv_from\x18\x04 \x03(\x0b\x32*.oak9.tython.k8s.api.core.v1.EnvFromSource\x12\r\n\x05image\x18\x05 \x01(\t\x12\x19\n\x11image_pull_policy\x18\x06 \x01(\t\x12\x39\n\tlifecycle\x18\x07 \x01(\x0b\x32&.oak9.tython.k8s.api.core.v1.Lifecycle\x12:\n\x0eliveness_probe\x18\x08 \x01(\x0b\x32\".oak9.tython.k8s.api.core.v1.Probe\x12\x0c\n\x04name\x18\t \x01(\t\x12\x39\n\x05ports\x18\n \x03(\x0b\x32*.oak9.tython.k8s.api.core.v1.ContainerPort\x12;\n\x0freadiness_probe\x18\x0b \x01(\x0b\x32\".oak9.tython.k8s.api.core.v1.Probe\x12\x44\n\tresources\x18\x0c \x01(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.ResourceRequirements\x12\x46\n\x10security_context\x18\r \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.SecurityContext\x12\x39\n\rstartup_probe\x18\x0e \x01(\x0b\x32\".oak9.tython.k8s.api.core.v1.Probe\x12\r\n\x05stdin\x18\x0f \x01(\x08\x12\x12\n\nstdin_once\x18\x10 \x01(\x08\x12 \n\x18termination_message_path\x18\x11 \x01(\t\x12\"\n\x1atermination_message_policy\x18\x12 \x01(\t\x12\x0b\n\x03tty\x18\x13 \x01(\x08\x12\x41\n\x0evolume_devices\x18\x14 \x03(\x0b\x32).oak9.tython.k8s.api.core.v1.VolumeDevice\x12?\n\rvolume_mounts\x18\x15 \x03(\x0b\x32(.oak9.tython.k8s.api.core.v1.VolumeMount\x12\x13\n\x0bworking_dir\x18\x16 \x01(\t\x12\x37\n\rresource_info\x18\x17 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"l\n\x0e\x43ontainerImage\x12\r\n\x05names\x18\x01 \x03(\t\x12\x12\n\nsize_bytes\x18\x02 \x01(\x05\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa4\x01\n\rContainerPort\x12\x16\n\x0e\x63ontainer_port\x18\x01 \x01(\x05\x12\x0f\n\x07host_ip\x18\x02 \x01(\t\x12\x11\n\thost_port\x18\x03 \x01(\x05\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08protocol\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9e\x02\n\x0e\x43ontainerState\x12\x43\n\x07running\x18\x01 \x01(\x0b\x32\x32.oak9.tython.k8s.api.core.v1.ContainerStateRunning\x12I\n\nterminated\x18\x02 \x01(\x0b\x32\x35.oak9.tython.k8s.api.core.v1.ContainerStateTerminated\x12\x43\n\x07waiting\x18\x03 \x01(\x0b\x32\x32.oak9.tython.k8s.api.core.v1.ContainerStateWaiting\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x99\x01\n\x15\x43ontainerStateRunning\x12G\n\nstarted_at\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc0\x02\n\x18\x43ontainerStateTerminated\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\x12\x11\n\texit_code\x18\x02 \x01(\x05\x12H\n\x0b\x66inished_at\x18\x03 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0e\n\x06signal\x18\x06 \x01(\x05\x12G\n\nstarted_at\x18\x07 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"q\n\x15\x43ontainerStateWaiting\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc3\x02\n\x0f\x43ontainerStatus\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x10\n\x08image_id\x18\x03 \x01(\t\x12?\n\nlast_state\x18\x04 \x01(\x0b\x32+.oak9.tython.k8s.api.core.v1.ContainerState\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\r\n\x05ready\x18\x06 \x01(\x08\x12\x15\n\rrestart_count\x18\x07 \x01(\x05\x12\x0f\n\x07started\x18\x08 \x01(\x08\x12:\n\x05state\x18\t \x01(\x0b\x32+.oak9.tython.k8s.api.core.v1.ContainerState\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"W\n\x0e\x44\x61\x65monEndpoint\x12\x0c\n\x04port\x18\x01 \x01(\x05\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x93\x01\n\x15\x44ownwardAPIProjection\x12\x41\n\x05items\x18\x01 \x03(\x0b\x32\x32.oak9.tython.k8s.api.core.v1.DownwardAPIVolumeFile\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x81\x02\n\x15\x44ownwardAPIVolumeFile\x12\x43\n\tfield_ref\x18\x01 \x01(\x0b\x32\x30.oak9.tython.k8s.api.core.v1.ObjectFieldSelector\x12\x0c\n\x04mode\x18\x02 \x01(\x05\x12\x0c\n\x04path\x18\x03 \x01(\t\x12N\n\x12resource_field_ref\x18\x04 \x01(\x0b\x32\x32.oak9.tython.k8s.api.core.v1.ResourceFieldSelector\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xab\x01\n\x17\x44ownwardAPIVolumeSource\x12\x14\n\x0c\x64\x65\x66\x61ult_mode\x18\x01 \x01(\x05\x12\x41\n\x05items\x18\x02 \x03(\x0b\x32\x32.oak9.tython.k8s.api.core.v1.DownwardAPIVolumeFile\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xac\x01\n\x14\x45mptyDirVolumeSource\x12\x0e\n\x06medium\x18\x01 \x01(\t\x12K\n\nsize_limit\x18\x02 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.api.resource.Quantity\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbd\x01\n\x0f\x45ndpointAddress\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x11\n\tnode_name\x18\x03 \x01(\t\x12@\n\ntarget_ref\x18\x04 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.ObjectReference\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8b\x01\n\x0c\x45ndpointPort\x12\x14\n\x0c\x61pp_protocol\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12\x10\n\x08protocol\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8f\x02\n\x0e\x45ndpointSubset\x12?\n\taddresses\x18\x01 \x03(\x0b\x32,.oak9.tython.k8s.api.core.v1.EndpointAddress\x12I\n\x13not_ready_addresses\x18\x02 \x03(\x0b\x32,.oak9.tython.k8s.api.core.v1.EndpointAddress\x12\x38\n\x05ports\x18\x03 \x03(\x0b\x32).oak9.tython.k8s.api.core.v1.EndpointPort\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf2\x01\n\tEndpoints\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12<\n\x07subsets\x18\x04 \x03(\x0b\x32+.oak9.tython.k8s.api.core.v1.EndpointSubset\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xed\x01\n\rEndpointsList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x35\n\x05items\x18\x02 \x03(\x0b\x32&.oak9.tython.k8s.api.core.v1.Endpoints\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe3\x01\n\rEnvFromSource\x12G\n\x0e\x63onfig_map_ref\x18\x01 \x01(\x0b\x32/.oak9.tython.k8s.api.core.v1.ConfigMapEnvSource\x12\x0e\n\x06prefix\x18\x02 \x01(\t\x12@\n\nsecret_ref\x18\x03 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.SecretEnvSource\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9d\x01\n\x06\x45nvVar\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12=\n\nvalue_from\x18\x03 \x01(\x0b\x32).oak9.tython.k8s.api.core.v1.EnvVarSource\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf3\x02\n\x0c\x45nvVarSource\x12M\n\x12\x63onfig_map_key_ref\x18\x01 \x01(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.ConfigMapKeySelector\x12\x43\n\tfield_ref\x18\x02 \x01(\x0b\x32\x30.oak9.tython.k8s.api.core.v1.ObjectFieldSelector\x12N\n\x12resource_field_ref\x18\x03 \x01(\x0b\x32\x32.oak9.tython.k8s.api.core.v1.ResourceFieldSelector\x12\x46\n\x0esecret_key_ref\x18\x04 \x01(\x0b\x32..oak9.tython.k8s.api.core.v1.SecretKeySelector\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xfa\x07\n\x12\x45phemeralContainer\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x03(\t\x12\x30\n\x03\x65nv\x18\x03 \x03(\x0b\x32#.oak9.tython.k8s.api.core.v1.EnvVar\x12<\n\x08\x65nv_from\x18\x04 \x03(\x0b\x32*.oak9.tython.k8s.api.core.v1.EnvFromSource\x12\r\n\x05image\x18\x05 \x01(\t\x12\x19\n\x11image_pull_policy\x18\x06 \x01(\t\x12\x39\n\tlifecycle\x18\x07 \x01(\x0b\x32&.oak9.tython.k8s.api.core.v1.Lifecycle\x12:\n\x0eliveness_probe\x18\x08 \x01(\x0b\x32\".oak9.tython.k8s.api.core.v1.Probe\x12\x0c\n\x04name\x18\t \x01(\t\x12\x39\n\x05ports\x18\n \x03(\x0b\x32*.oak9.tython.k8s.api.core.v1.ContainerPort\x12;\n\x0freadiness_probe\x18\x0b \x01(\x0b\x32\".oak9.tython.k8s.api.core.v1.Probe\x12\x44\n\tresources\x18\x0c \x01(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.ResourceRequirements\x12\x46\n\x10security_context\x18\r \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.SecurityContext\x12\x39\n\rstartup_probe\x18\x0e \x01(\x0b\x32\".oak9.tython.k8s.api.core.v1.Probe\x12\r\n\x05stdin\x18\x0f \x01(\x08\x12\x12\n\nstdin_once\x18\x10 \x01(\x08\x12\x1d\n\x15target_container_name\x18\x11 \x01(\t\x12 \n\x18termination_message_path\x18\x12 \x01(\t\x12\"\n\x1atermination_message_policy\x18\x13 \x01(\t\x12\x0b\n\x03tty\x18\x14 \x01(\x08\x12\x41\n\x0evolume_devices\x18\x15 \x03(\x0b\x32).oak9.tython.k8s.api.core.v1.VolumeDevice\x12?\n\rvolume_mounts\x18\x16 \x03(\x0b\x32(.oak9.tython.k8s.api.core.v1.VolumeMount\x12\x13\n\x0bworking_dir\x18\x17 \x01(\t\x12\x37\n\rresource_info\x18\x18 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xab\x01\n\x15\x45phemeralVolumeSource\x12Y\n\x15volume_claim_template\x18\x01 \x01(\x0b\x32:.oak9.tython.k8s.api.core.v1.PersistentVolumeClaimTemplate\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9a\x06\n\x05\x45vent\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x13\n\x0b\x61pi_version\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\x12L\n\nevent_time\x18\x04 \x01(\x0b\x32\x38.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.MicroTime\x12L\n\x0f\x66irst_timestamp\x18\x05 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x45\n\x0finvolved_object\x18\x06 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.ObjectReference\x12\x0c\n\x04kind\x18\x07 \x01(\t\x12K\n\x0elast_timestamp\x18\x08 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\t \x01(\t\x12K\n\x08metadata\x18\n \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x0e\n\x06reason\x18\x0b \x01(\t\x12=\n\x07related\x18\x0c \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.ObjectReference\x12\x1b\n\x13reporting_component\x18\r \x01(\t\x12\x1a\n\x12reporting_instance\x18\x0e \x01(\t\x12\x38\n\x06series\x18\x0f \x01(\x0b\x32(.oak9.tython.k8s.api.core.v1.EventSeries\x12\x38\n\x06source\x18\x10 \x01(\x0b\x32(.oak9.tython.k8s.api.core.v1.EventSource\x12\x0c\n\x04type\x18\x11 \x01(\t\x12\x37\n\rresource_info\x18\x12 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe5\x01\n\tEventList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x31\n\x05items\x18\x02 \x03(\x0b\x32\".oak9.tython.k8s.api.core.v1.Event\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xab\x01\n\x0b\x45ventSeries\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12T\n\x12last_observed_time\x18\x02 \x01(\x0b\x32\x38.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.MicroTime\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"g\n\x0b\x45ventSource\x12\x11\n\tcomponent\x18\x01 \x01(\t\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"V\n\nExecAction\x12\x0f\n\x07\x63ommand\x18\x01 \x03(\t\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa0\x01\n\x0e\x46\x43VolumeSource\x12\x0f\n\x07\x66s_type\x18\x01 \x01(\t\x12\x0b\n\x03lun\x18\x02 \x01(\x05\x12\x11\n\tread_only\x18\x03 \x01(\x08\x12\x15\n\rtarget_w_w_ns\x18\x04 \x03(\t\x12\r\n\x05wwids\x18\x05 \x03(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd2\x02\n\x1a\x46lexPersistentVolumeSource\x12\x0e\n\x06\x64river\x18\x01 \x01(\t\x12\x0f\n\x07\x66s_type\x18\x02 \x01(\t\x12U\n\x07options\x18\x03 \x03(\x0b\x32\x44.oak9.tython.k8s.api.core.v1.FlexPersistentVolumeSource.OptionsEntry\x12\x11\n\tread_only\x18\x04 \x01(\x08\x12@\n\nsecret_ref\x18\x05 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.SecretReference\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc3\x02\n\x10\x46lexVolumeSource\x12\x0e\n\x06\x64river\x18\x01 \x01(\t\x12\x0f\n\x07\x66s_type\x18\x02 \x01(\t\x12K\n\x07options\x18\x03 \x03(\x0b\x32:.oak9.tython.k8s.api.core.v1.FlexVolumeSource.OptionsEntry\x12\x11\n\tread_only\x18\x04 \x01(\x08\x12\x45\n\nsecret_ref\x18\x05 \x01(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.LocalObjectReference\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"|\n\x13\x46lockerVolumeSource\x12\x14\n\x0c\x64\x61taset_name\x18\x01 \x01(\t\x12\x16\n\x0e\x64\x61taset_u_u_id\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa0\x01\n\x1dGCEPersistentDiskVolumeSource\x12\x0f\n\x07\x66s_type\x18\x01 \x01(\t\x12\x11\n\tpartition\x18\x02 \x01(\x05\x12\x0f\n\x07pd_name\x18\x03 \x01(\t\x12\x11\n\tread_only\x18\x04 \x01(\x08\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"d\n\nGRPCAction\x12\x0c\n\x04port\x18\x01 \x01(\x05\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x87\x01\n\x13GitRepoVolumeSource\x12\x11\n\tdirectory\x18\x01 \x01(\t\x12\x12\n\nrepository\x18\x02 \x01(\t\x12\x10\n\x08revision\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xab\x01\n\x1fGlusterfsPersistentVolumeSource\x12\x11\n\tendpoints\x18\x01 \x01(\t\x12\x1b\n\x13\x65ndpoints_namespace\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x11\n\tread_only\x18\x04 \x01(\x08\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x84\x01\n\x15GlusterfsVolumeSource\x12\x11\n\tendpoints\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x11\n\tread_only\x18\x03 \x01(\x08\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xfc\x01\n\rHTTPGetAction\x12\x0c\n\x04host\x18\x01 \x01(\t\x12=\n\x0chttp_headers\x18\x02 \x03(\x0b\x32\'.oak9.tython.k8s.api.core.v1.HTTPHeader\x12\x0c\n\x04path\x18\x03 \x01(\t\x12G\n\x04port\x18\x04 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.util.intstr.IntOrString\x12\x0e\n\x06scheme\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"b\n\nHTTPHeader\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"c\n\tHostAlias\x12\x11\n\thostnames\x18\x01 \x03(\t\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"k\n\x14HostPathVolumeSource\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe7\x02\n\x1bISCSIPersistentVolumeSource\x12\x1b\n\x13\x63hap_auth_discovery\x18\x01 \x01(\x08\x12\x19\n\x11\x63hap_auth_session\x18\x02 \x01(\x08\x12\x0f\n\x07\x66s_type\x18\x03 \x01(\t\x12\x16\n\x0einitiator_name\x18\x04 \x01(\t\x12\x0b\n\x03iqn\x18\x05 \x01(\t\x12\x17\n\x0fiscsi_interface\x18\x06 \x01(\t\x12\x0b\n\x03lun\x18\x07 \x01(\x05\x12\x0f\n\x07portals\x18\x08 \x03(\t\x12\x11\n\tread_only\x18\t \x01(\x08\x12@\n\nsecret_ref\x18\n \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.SecretReference\x12\x15\n\rtarget_portal\x18\x0b \x01(\t\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe2\x02\n\x11ISCSIVolumeSource\x12\x1b\n\x13\x63hap_auth_discovery\x18\x01 \x01(\x08\x12\x19\n\x11\x63hap_auth_session\x18\x02 \x01(\x08\x12\x0f\n\x07\x66s_type\x18\x03 \x01(\t\x12\x16\n\x0einitiator_name\x18\x04 \x01(\t\x12\x0b\n\x03iqn\x18\x05 \x01(\t\x12\x17\n\x0fiscsi_interface\x18\x06 \x01(\t\x12\x0b\n\x03lun\x18\x07 \x01(\x05\x12\x0f\n\x07portals\x18\x08 \x03(\t\x12\x11\n\tread_only\x18\t \x01(\x08\x12\x45\n\nsecret_ref\x18\n \x01(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.LocalObjectReference\x12\x15\n\rtarget_portal\x18\x0b \x01(\t\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"m\n\tKeyToPath\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04mode\x18\x02 \x01(\x05\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc8\x01\n\tLifecycle\x12\x41\n\npost_start\x18\x01 \x01(\x0b\x32-.oak9.tython.k8s.api.core.v1.LifecycleHandler\x12?\n\x08pre_stop\x18\x02 \x01(\x0b\x32-.oak9.tython.k8s.api.core.v1.LifecycleHandler\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x82\x02\n\x10LifecycleHandler\x12\x35\n\x04\x65xec\x18\x01 \x01(\x0b\x32\'.oak9.tython.k8s.api.core.v1.ExecAction\x12<\n\x08http_get\x18\x02 \x01(\x0b\x32*.oak9.tython.k8s.api.core.v1.HTTPGetAction\x12@\n\ntcp_socket\x18\x03 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.TCPSocketAction\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf0\x01\n\nLimitRange\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x39\n\x04spec\x18\x04 \x01(\x0b\x32+.oak9.tython.k8s.api.core.v1.LimitRangeSpec\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe6\x05\n\x0eLimitRangeItem\x12I\n\x07\x64\x65\x66\x61ult\x18\x01 \x03(\x0b\x32\x38.oak9.tython.k8s.api.core.v1.LimitRangeItem.DefaultEntry\x12X\n\x0f\x64\x65\x66\x61ult_request\x18\x02 \x03(\x0b\x32?.oak9.tython.k8s.api.core.v1.LimitRangeItem.DefaultRequestEntry\x12\x41\n\x03max\x18\x03 \x03(\x0b\x32\x34.oak9.tython.k8s.api.core.v1.LimitRangeItem.MaxEntry\x12\x66\n\x17max_limit_request_ratio\x18\x04 \x03(\x0b\x32\x45.oak9.tython.k8s.api.core.v1.LimitRangeItem.MaxLimitRequestRatioEntry\x12\x41\n\x03min\x18\x05 \x03(\x0b\x32\x34.oak9.tython.k8s.api.core.v1.LimitRangeItem.MinEntry\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a.\n\x0c\x44\x65\x66\x61ultEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x35\n\x13\x44\x65\x66\x61ultRequestEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a*\n\x08MaxEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a;\n\x19MaxLimitRequestRatioEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a*\n\x08MinEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xef\x01\n\x0eLimitRangeList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x36\n\x05items\x18\x02 \x03(\x0b\x32\'.oak9.tython.k8s.api.core.v1.LimitRange\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x86\x01\n\x0eLimitRangeSpec\x12;\n\x06limits\x18\x01 \x03(\x0b\x32+.oak9.tython.k8s.api.core.v1.LimitRangeItem\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa4\x01\n\x13LoadBalancerIngress\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x36\n\x05ports\x18\x03 \x03(\x0b\x32\'.oak9.tython.k8s.api.core.v1.PortStatus\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x90\x01\n\x12LoadBalancerStatus\x12\x41\n\x07ingress\x18\x01 \x03(\x0b\x32\x30.oak9.tython.k8s.api.core.v1.LoadBalancerIngress\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"]\n\x14LocalObjectReference\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"k\n\x11LocalVolumeSource\x12\x0f\n\x07\x66s_type\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"{\n\x0fNFSVolumeSource\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tread_only\x18\x02 \x01(\x08\x12\x0e\n\x06server\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xac\x02\n\tNamespace\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x38\n\x04spec\x18\x04 \x01(\x0b\x32*.oak9.tython.k8s.api.core.v1.NamespaceSpec\x12<\n\x06status\x18\x05 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.NamespaceStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xdf\x01\n\x12NamespaceCondition\x12Q\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xed\x01\n\rNamespaceList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x35\n\x05items\x18\x02 \x03(\x0b\x32&.oak9.tython.k8s.api.core.v1.Namespace\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\\\n\rNamespaceSpec\x12\x12\n\nfinalizers\x18\x01 \x03(\t\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9e\x01\n\x0fNamespaceStatus\x12\x43\n\nconditions\x18\x01 \x03(\x0b\x32/.oak9.tython.k8s.api.core.v1.NamespaceCondition\x12\r\n\x05phase\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9d\x02\n\x04Node\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x33\n\x04spec\x18\x04 \x01(\x0b\x32%.oak9.tython.k8s.api.core.v1.NodeSpec\x12\x37\n\x06status\x18\x05 \x01(\x0b\x32\'.oak9.tython.k8s.api.core.v1.NodeStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"e\n\x0bNodeAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa3\x02\n\x0cNodeAffinity\x12r\n4preferred_during_scheduling_ignored_during_execution\x18\x01 \x03(\x0b\x32\x34.oak9.tython.k8s.api.core.v1.PreferredSchedulingTerm\x12\x66\n3required_during_scheduling_ignored_during_execution\x18\x02 \x01(\x0b\x32).oak9.tython.k8s.api.core.v1.NodeSelector\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xac\x02\n\rNodeCondition\x12P\n\x13last_heartbeat_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12Q\n\x14last_transition_time\x18\x02 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x97\x01\n\x10NodeConfigSource\x12J\n\nconfig_map\x18\x01 \x01(\x0b\x32\x36.oak9.tython.k8s.api.core.v1.ConfigMapNodeConfigSource\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa2\x02\n\x10NodeConfigStatus\x12=\n\x06\x61\x63tive\x18\x01 \x01(\x0b\x32-.oak9.tython.k8s.api.core.v1.NodeConfigSource\x12?\n\x08\x61ssigned\x18\x02 \x01(\x0b\x32-.oak9.tython.k8s.api.core.v1.NodeConfigSource\x12\r\n\x05\x65rror\x18\x03 \x01(\t\x12\x46\n\x0flast_known_good\x18\x04 \x01(\x0b\x32-.oak9.tython.k8s.api.core.v1.NodeConfigSource\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x95\x01\n\x13NodeDaemonEndpoints\x12\x45\n\x10kubelet_endpoint\x18\x01 \x01(\x0b\x32+.oak9.tython.k8s.api.core.v1.DaemonEndpoint\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe3\x01\n\x08NodeList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x30\n\x05items\x18\x02 \x03(\x0b\x32!.oak9.tython.k8s.api.core.v1.Node\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x93\x01\n\x0cNodeSelector\x12J\n\x13node_selector_terms\x18\x01 \x03(\x0b\x32-.oak9.tython.k8s.api.core.v1.NodeSelectorTerm\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x81\x01\n\x17NodeSelectorRequirement\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe8\x01\n\x10NodeSelectorTerm\x12O\n\x11match_expressions\x18\x01 \x03(\x0b\x32\x34.oak9.tython.k8s.api.core.v1.NodeSelectorRequirement\x12J\n\x0cmatch_fields\x18\x02 \x03(\x0b\x32\x34.oak9.tython.k8s.api.core.v1.NodeSelectorRequirement\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa3\x02\n\x08NodeSpec\x12\x44\n\rconfig_source\x18\x01 \x01(\x0b\x32-.oak9.tython.k8s.api.core.v1.NodeConfigSource\x12\x13\n\x0b\x65xternal_id\x18\x02 \x01(\t\x12\x10\n\x08pod_cidr\x18\x03 \x01(\t\x12\x11\n\tpod_cidrs\x18\x04 \x03(\t\x12\x13\n\x0bprovider_id\x18\x05 \x01(\t\x12\x32\n\x06taints\x18\x06 \x03(\x0b\x32\".oak9.tython.k8s.api.core.v1.Taint\x12\x15\n\runschedulable\x18\x07 \x01(\x08\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb5\x06\n\nNodeStatus\x12;\n\taddresses\x18\x01 \x03(\x0b\x32(.oak9.tython.k8s.api.core.v1.NodeAddress\x12M\n\x0b\x61llocatable\x18\x02 \x03(\x0b\x32\x38.oak9.tython.k8s.api.core.v1.NodeStatus.AllocatableEntry\x12G\n\x08\x63\x61pacity\x18\x03 \x03(\x0b\x32\x35.oak9.tython.k8s.api.core.v1.NodeStatus.CapacityEntry\x12>\n\nconditions\x18\x04 \x03(\x0b\x32*.oak9.tython.k8s.api.core.v1.NodeCondition\x12=\n\x06\x63onfig\x18\x05 \x01(\x0b\x32-.oak9.tython.k8s.api.core.v1.NodeConfigStatus\x12J\n\x10\x64\x61\x65mon_endpoints\x18\x06 \x01(\x0b\x32\x30.oak9.tython.k8s.api.core.v1.NodeDaemonEndpoints\x12;\n\x06images\x18\x07 \x03(\x0b\x32+.oak9.tython.k8s.api.core.v1.ContainerImage\x12>\n\tnode_info\x18\x08 \x01(\x0b\x32+.oak9.tython.k8s.api.core.v1.NodeSystemInfo\x12\r\n\x05phase\x18\t \x01(\t\x12\x45\n\x10volumes_attached\x18\n \x03(\x0b\x32+.oak9.tython.k8s.api.core.v1.AttachedVolume\x12\x16\n\x0evolumes_in_use\x18\x0b \x03(\t\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10\x41llocatableEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rCapacityEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb7\x02\n\x0eNodeSystemInfo\x12\x14\n\x0c\x61rchitecture\x18\x01 \x01(\t\x12\x0f\n\x07\x62oot_id\x18\x02 \x01(\t\x12!\n\x19\x63ontainer_runtime_version\x18\x03 \x01(\t\x12\x16\n\x0ekernel_version\x18\x04 \x01(\t\x12\x1a\n\x12kube_proxy_version\x18\x05 \x01(\t\x12\x17\n\x0fkubelet_version\x18\x06 \x01(\t\x12\x12\n\nmachine_id\x18\x07 \x01(\t\x12\x18\n\x10operating_system\x18\x08 \x01(\t\x12\x10\n\x08os_image\x18\t \x01(\t\x12\x15\n\rsystem_u_u_id\x18\n \x01(\t\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"w\n\x13ObjectFieldSelector\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x12\n\nfield_path\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc9\x01\n\x0fObjectReference\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x12\n\nfield_path\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x11\n\tnamespace\x18\x05 \x01(\t\x12\x18\n\x10resource_version\x18\x06 \x01(\t\x12\x0b\n\x03uid\x18\x07 \x01(\t\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc1\x02\n\x10PersistentVolume\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12?\n\x04spec\x18\x04 \x01(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.PersistentVolumeSpec\x12\x43\n\x06status\x18\x05 \x01(\x0b\x32\x33.oak9.tython.k8s.api.core.v1.PersistentVolumeStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd0\x02\n\x15PersistentVolumeClaim\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x44\n\x04spec\x18\x04 \x01(\x0b\x32\x36.oak9.tython.k8s.api.core.v1.PersistentVolumeClaimSpec\x12H\n\x06status\x18\x05 \x01(\x0b\x32\x38.oak9.tython.k8s.api.core.v1.PersistentVolumeClaimStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb9\x02\n\x1ePersistentVolumeClaimCondition\x12L\n\x0flast_probe_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12Q\n\x14last_transition_time\x18\x02 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x85\x02\n\x19PersistentVolumeClaimList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x41\n\x05items\x18\x02 \x03(\x0b\x32\x32.oak9.tython.k8s.api.core.v1.PersistentVolumeClaim\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xdf\x03\n\x19PersistentVolumeClaimSpec\x12\x14\n\x0c\x61\x63\x63\x65ss_modes\x18\x01 \x03(\t\x12K\n\x0b\x64\x61ta_source\x18\x02 \x01(\x0b\x32\x36.oak9.tython.k8s.api.core.v1.TypedLocalObjectReference\x12J\n\x0f\x64\x61ta_source_ref\x18\x03 \x01(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.TypedObjectReference\x12\x44\n\tresources\x18\x04 \x01(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.ResourceRequirements\x12N\n\x08selector\x18\x05 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x1a\n\x12storage_class_name\x18\x06 \x01(\t\x12\x13\n\x0bvolume_mode\x18\x07 \x01(\t\x12\x13\n\x0bvolume_name\x18\x08 \x01(\t\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x98\x04\n\x1bPersistentVolumeClaimStatus\x12\x14\n\x0c\x61\x63\x63\x65ss_modes\x18\x01 \x03(\t\x12m\n\x13\x61llocated_resources\x18\x02 \x03(\x0b\x32P.oak9.tython.k8s.api.core.v1.PersistentVolumeClaimStatus.AllocatedResourcesEntry\x12X\n\x08\x63\x61pacity\x18\x03 \x03(\x0b\x32\x46.oak9.tython.k8s.api.core.v1.PersistentVolumeClaimStatus.CapacityEntry\x12O\n\nconditions\x18\x04 \x03(\x0b\x32;.oak9.tython.k8s.api.core.v1.PersistentVolumeClaimCondition\x12\r\n\x05phase\x18\x05 \x01(\t\x12\x15\n\rresize_status\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x39\n\x17\x41llocatedResourcesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rCapacityEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xeb\x01\n\x1dPersistentVolumeClaimTemplate\x12K\n\x08metadata\x18\x01 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x44\n\x04spec\x18\x02 \x01(\x0b\x32\x36.oak9.tython.k8s.api.core.v1.PersistentVolumeClaimSpec\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x83\x01\n!PersistentVolumeClaimVolumeSource\x12\x12\n\nclaim_name\x18\x01 \x01(\t\x12\x11\n\tread_only\x18\x02 \x01(\x08\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xfb\x01\n\x14PersistentVolumeList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12<\n\x05items\x18\x02 \x03(\x0b\x32-.oak9.tython.k8s.api.core.v1.PersistentVolume\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xdd\x10\n\x14PersistentVolumeSpec\x12\x14\n\x0c\x61\x63\x63\x65ss_modes\x18\x01 \x03(\t\x12^\n\x17\x61ws_elastic_block_store\x18\x02 \x01(\x0b\x32=.oak9.tython.k8s.api.core.v1.AWSElasticBlockStoreVolumeSource\x12\x46\n\nazure_disk\x18\x03 \x01(\x0b\x32\x32.oak9.tython.k8s.api.core.v1.AzureDiskVolumeSource\x12P\n\nazure_file\x18\x04 \x01(\x0b\x32<.oak9.tython.k8s.api.core.v1.AzureFilePersistentVolumeSource\x12Q\n\x08\x63\x61pacity\x18\x05 \x03(\x0b\x32?.oak9.tython.k8s.api.core.v1.PersistentVolumeSpec.CapacityEntry\x12I\n\x06\x63\x65phfs\x18\x06 \x01(\x0b\x32\x39.oak9.tython.k8s.api.core.v1.CephFSPersistentVolumeSource\x12I\n\x06\x63inder\x18\x07 \x01(\x0b\x32\x39.oak9.tython.k8s.api.core.v1.CinderPersistentVolumeSource\x12?\n\tclaim_ref\x18\x08 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.ObjectReference\x12\x43\n\x03\x63si\x18\t \x01(\x0b\x32\x36.oak9.tython.k8s.api.core.v1.CSIPersistentVolumeSource\x12\x37\n\x02\x66\x63\x18\n \x01(\x0b\x32+.oak9.tython.k8s.api.core.v1.FCVolumeSource\x12L\n\x0b\x66lex_volume\x18\x0b \x01(\x0b\x32\x37.oak9.tython.k8s.api.core.v1.FlexPersistentVolumeSource\x12\x41\n\x07\x66locker\x18\x0c \x01(\x0b\x32\x30.oak9.tython.k8s.api.core.v1.FlockerVolumeSource\x12W\n\x13gce_persistent_disk\x18\r \x01(\x0b\x32:.oak9.tython.k8s.api.core.v1.GCEPersistentDiskVolumeSource\x12O\n\tglusterfs\x18\x0e \x01(\x0b\x32<.oak9.tython.k8s.api.core.v1.GlusterfsPersistentVolumeSource\x12\x44\n\thost_path\x18\x0f \x01(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.HostPathVolumeSource\x12G\n\x05iscsi\x18\x10 \x01(\x0b\x32\x38.oak9.tython.k8s.api.core.v1.ISCSIPersistentVolumeSource\x12=\n\x05local\x18\x11 \x01(\x0b\x32..oak9.tython.k8s.api.core.v1.LocalVolumeSource\x12\x15\n\rmount_options\x18\x12 \x03(\t\x12\x39\n\x03nfs\x18\x13 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.NFSVolumeSource\x12\x46\n\rnode_affinity\x18\x14 \x01(\x0b\x32/.oak9.tython.k8s.api.core.v1.VolumeNodeAffinity\x12(\n persistent_volume_reclaim_policy\x18\x15 \x01(\t\x12]\n\x16photon_persistent_disk\x18\x16 \x01(\x0b\x32=.oak9.tython.k8s.api.core.v1.PhotonPersistentDiskVolumeSource\x12J\n\x0fportworx_volume\x18\x17 \x01(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.PortworxVolumeSource\x12\x41\n\x07quobyte\x18\x18 \x01(\x0b\x32\x30.oak9.tython.k8s.api.core.v1.QuobyteVolumeSource\x12\x43\n\x03rbd\x18\x19 \x01(\x0b\x32\x36.oak9.tython.k8s.api.core.v1.RBDPersistentVolumeSource\x12L\n\x08scale_io\x18\x1a \x01(\x0b\x32:.oak9.tython.k8s.api.core.v1.ScaleIOPersistentVolumeSource\x12\x1a\n\x12storage_class_name\x18\x1b \x01(\t\x12O\n\tstorageos\x18\x1c \x01(\x0b\x32<.oak9.tython.k8s.api.core.v1.StorageOSPersistentVolumeSource\x12\x13\n\x0bvolume_mode\x18\x1d \x01(\t\x12S\n\x0evsphere_volume\x18\x1e \x01(\x0b\x32;.oak9.tython.k8s.api.core.v1.VsphereVirtualDiskVolumeSource\x12\x37\n\rresource_info\x18\x1f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a/\n\rCapacityEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x81\x01\n\x16PersistentVolumeStatus\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\r\n\x05phase\x18\x02 \x01(\t\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"{\n PhotonPersistentDiskVolumeSource\x12\x0f\n\x07\x66s_type\x18\x01 \x01(\t\x12\r\n\x05pd_id\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9a\x02\n\x03Pod\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x32\n\x04spec\x18\x04 \x01(\x0b\x32$.oak9.tython.k8s.api.core.v1.PodSpec\x12\x36\n\x06status\x18\x05 \x01(\x0b\x32&.oak9.tython.k8s.api.core.v1.PodStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa5\x02\n\x0bPodAffinity\x12r\n4preferred_during_scheduling_ignored_during_execution\x18\x01 \x03(\x0b\x32\x34.oak9.tython.k8s.api.core.v1.WeightedPodAffinityTerm\x12i\n3required_during_scheduling_ignored_during_execution\x18\x02 \x03(\x0b\x32,.oak9.tython.k8s.api.core.v1.PodAffinityTerm\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa4\x02\n\x0fPodAffinityTerm\x12T\n\x0elabel_selector\x18\x01 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12X\n\x12namespace_selector\x18\x02 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x12\n\nnamespaces\x18\x03 \x03(\t\x12\x14\n\x0ctopology_key\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa9\x02\n\x0fPodAntiAffinity\x12r\n4preferred_during_scheduling_ignored_during_execution\x18\x01 \x03(\x0b\x32\x34.oak9.tython.k8s.api.core.v1.WeightedPodAffinityTerm\x12i\n3required_during_scheduling_ignored_during_execution\x18\x02 \x03(\x0b\x32,.oak9.tython.k8s.api.core.v1.PodAffinityTerm\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa7\x02\n\x0cPodCondition\x12L\n\x0flast_probe_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12Q\n\x14last_transition_time\x18\x02 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb0\x01\n\x0cPodDNSConfig\x12\x13\n\x0bnameservers\x18\x01 \x03(\t\x12@\n\x07options\x18\x02 \x03(\x0b\x32/.oak9.tython.k8s.api.core.v1.PodDNSConfigOption\x12\x10\n\x08searches\x18\x03 \x03(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"j\n\x12PodDNSConfigOption\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"L\n\x05PodIP\x12\n\n\x02ip\x18\x01 \x01(\t\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe1\x01\n\x07PodList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12/\n\x05items\x18\x02 \x03(\x0b\x32 .oak9.tython.k8s.api.core.v1.Pod\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"N\n\x05PodOS\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"c\n\x10PodReadinessGate\x12\x16\n\x0e\x63ondition_type\x18\x01 \x01(\t\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x93\x01\n\x10PodResourceClaim\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x38\n\x06source\x18\x02 \x01(\x0b\x32(.oak9.tython.k8s.api.core.v1.ClaimSource\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Z\n\x11PodSchedulingGate\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf8\x03\n\x12PodSecurityContext\x12\x10\n\x08\x66s_group\x18\x01 \x01(\x05\x12\x1e\n\x16\x66s_group_change_policy\x18\x02 \x01(\t\x12\x14\n\x0crun_as_group\x18\x03 \x01(\x05\x12\x17\n\x0frun_as_non_root\x18\x04 \x01(\x08\x12\x13\n\x0brun_as_user\x18\x05 \x01(\x05\x12\x45\n\x10se_linux_options\x18\x06 \x01(\x0b\x32+.oak9.tython.k8s.api.core.v1.SELinuxOptions\x12\x44\n\x0fseccomp_profile\x18\x07 \x01(\x0b\x32+.oak9.tython.k8s.api.core.v1.SeccompProfile\x12\x1b\n\x13supplemental_groups\x18\x08 \x03(\x03\x12\x34\n\x07sysctls\x18\t \x03(\x0b\x32#.oak9.tython.k8s.api.core.v1.Sysctl\x12S\n\x0fwindows_options\x18\n \x01(\x0b\x32:.oak9.tython.k8s.api.core.v1.WindowsSecurityContextOptions\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xed\x0e\n\x07PodSpec\x12\x1f\n\x17\x61\x63tive_deadline_seconds\x18\x01 \x01(\x05\x12\x37\n\x08\x61\x66\x66inity\x18\x02 \x01(\x0b\x32%.oak9.tython.k8s.api.core.v1.Affinity\x12\'\n\x1f\x61utomount_service_account_token\x18\x03 \x01(\x08\x12:\n\ncontainers\x18\x04 \x03(\x0b\x32&.oak9.tython.k8s.api.core.v1.Container\x12=\n\ndns_config\x18\x05 \x01(\x0b\x32).oak9.tython.k8s.api.core.v1.PodDNSConfig\x12\x12\n\ndns_policy\x18\x06 \x01(\t\x12\x1c\n\x14\x65nable_service_links\x18\x07 \x01(\x08\x12M\n\x14\x65phemeral_containers\x18\x08 \x03(\x0b\x32/.oak9.tython.k8s.api.core.v1.EphemeralContainer\x12<\n\x0chost_aliases\x18\t \x03(\x0b\x32&.oak9.tython.k8s.api.core.v1.HostAlias\x12\x11\n\thost_ip_c\x18\n \x01(\x08\x12\x14\n\x0chost_network\x18\x0b \x01(\x08\x12\x11\n\thost_p_id\x18\x0c \x01(\x08\x12\x12\n\nhost_users\x18\r \x01(\x08\x12\x10\n\x08hostname\x18\x0e \x01(\t\x12M\n\x12image_pull_secrets\x18\x0f \x03(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.LocalObjectReference\x12?\n\x0finit_containers\x18\x10 \x03(\x0b\x32&.oak9.tython.k8s.api.core.v1.Container\x12\x11\n\tnode_name\x18\x11 \x01(\t\x12M\n\rnode_selector\x18\x12 \x03(\x0b\x32\x36.oak9.tython.k8s.api.core.v1.PodSpec.NodeSelectorEntry\x12.\n\x02os\x18\x13 \x01(\x0b\x32\".oak9.tython.k8s.api.core.v1.PodOS\x12\x44\n\x08overhead\x18\x14 \x03(\x0b\x32\x32.oak9.tython.k8s.api.core.v1.PodSpec.OverheadEntry\x12\x19\n\x11preemption_policy\x18\x15 \x01(\t\x12\x10\n\x08priority\x18\x16 \x01(\x05\x12\x1b\n\x13priority_class_name\x18\x17 \x01(\t\x12\x46\n\x0freadiness_gates\x18\x18 \x03(\x0b\x32-.oak9.tython.k8s.api.core.v1.PodReadinessGate\x12\x46\n\x0fresource_claims\x18\x19 \x03(\x0b\x32-.oak9.tython.k8s.api.core.v1.PodResourceClaim\x12\x16\n\x0erestart_policy\x18\x1a \x01(\t\x12\x1a\n\x12runtime_class_name\x18\x1b \x01(\t\x12\x16\n\x0escheduler_name\x18\x1c \x01(\t\x12H\n\x10scheduling_gates\x18\x1d \x03(\x0b\x32..oak9.tython.k8s.api.core.v1.PodSchedulingGate\x12I\n\x10security_context\x18\x1e \x01(\x0b\x32/.oak9.tython.k8s.api.core.v1.PodSecurityContext\x12\x17\n\x0fservice_account\x18\x1f \x01(\t\x12\x1c\n\x14service_account_name\x18  \x01(\t\x12\x1c\n\x14set_hostname_as_fqdn\x18! \x01(\x08\x12\x1f\n\x17share_process_namespace\x18\" \x01(\x08\x12\x11\n\tsubdomain\x18# \x01(\t\x12(\n termination_grace_period_seconds\x18$ \x01(\x05\x12<\n\x0btolerations\x18% \x03(\x0b\x32\'.oak9.tython.k8s.api.core.v1.Toleration\x12Z\n\x1btopology_spread_constraints\x18& \x03(\x0b\x32\x35.oak9.tython.k8s.api.core.v1.TopologySpreadConstraint\x12\x34\n\x07volumes\x18\' \x03(\x0b\x32#.oak9.tython.k8s.api.core.v1.Volume\x12\x37\n\rresource_info\x18( \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x33\n\x11NodeSelectorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rOverheadEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xef\x04\n\tPodStatus\x12=\n\nconditions\x18\x01 \x03(\x0b\x32).oak9.tython.k8s.api.core.v1.PodCondition\x12H\n\x12\x63ontainer_statuses\x18\x02 \x03(\x0b\x32,.oak9.tython.k8s.api.core.v1.ContainerStatus\x12R\n\x1c\x65phemeral_container_statuses\x18\x03 \x03(\x0b\x32,.oak9.tython.k8s.api.core.v1.ContainerStatus\x12\x0f\n\x07host_ip\x18\x04 \x01(\t\x12M\n\x17init_container_statuses\x18\x05 \x03(\x0b\x32,.oak9.tython.k8s.api.core.v1.ContainerStatus\x12\x0f\n\x07message\x18\x06 \x01(\t\x12\x1b\n\x13nominated_node_name\x18\x07 \x01(\t\x12\r\n\x05phase\x18\x08 \x01(\t\x12\x0e\n\x06pod_ip\x18\t \x01(\t\x12\x33\n\x07pod_ips\x18\n \x03(\x0b\x32\".oak9.tython.k8s.api.core.v1.PodIP\x12\x11\n\tqos_class\x18\x0b \x01(\t\x12\x0e\n\x06reason\x18\x0c \x01(\t\x12G\n\nstart_time\x18\r \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf6\x01\n\x0bPodTemplate\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12>\n\x08template\x18\x04 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.PodTemplateSpec\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf1\x01\n\x0fPodTemplateList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x37\n\x05items\x18\x02 \x03(\x0b\x32(.oak9.tython.k8s.api.core.v1.PodTemplate\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xcb\x01\n\x0fPodTemplateSpec\x12K\n\x08metadata\x18\x01 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x32\n\x04spec\x18\x02 \x01(\x0b\x32$.oak9.tython.k8s.api.core.v1.PodSpec\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"t\n\nPortStatus\x12\r\n\x05\x65rror\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x10\n\x08protocol\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x86\x01\n\x14PortworxVolumeSource\x12\x0f\n\x07\x66s_type\x18\x01 \x01(\t\x12\x11\n\tread_only\x18\x02 \x01(\x08\x12\x11\n\tvolume_id\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa5\x01\n\x17PreferredSchedulingTerm\x12\x41\n\npreference\x18\x01 \x01(\x0b\x32-.oak9.tython.k8s.api.core.v1.NodeSelectorTerm\x12\x0e\n\x06weight\x18\x02 \x01(\x05\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xde\x03\n\x05Probe\x12\x35\n\x04\x65xec\x18\x01 \x01(\x0b\x32\'.oak9.tython.k8s.api.core.v1.ExecAction\x12\x19\n\x11\x66\x61ilure_threshold\x18\x02 \x01(\x05\x12\x35\n\x04grpc\x18\x03 \x01(\x0b\x32\'.oak9.tython.k8s.api.core.v1.GRPCAction\x12<\n\x08http_get\x18\x04 \x01(\x0b\x32*.oak9.tython.k8s.api.core.v1.HTTPGetAction\x12\x1d\n\x15initial_delay_seconds\x18\x05 \x01(\x05\x12\x16\n\x0eperiod_seconds\x18\x06 \x01(\x05\x12\x19\n\x11success_threshold\x18\x07 \x01(\x05\x12@\n\ntcp_socket\x18\x08 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.TCPSocketAction\x12(\n termination_grace_period_seconds\x18\t \x01(\x05\x12\x17\n\x0ftimeout_seconds\x18\n \x01(\x05\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa6\x01\n\x15ProjectedVolumeSource\x12\x14\n\x0c\x64\x65\x66\x61ult_mode\x18\x01 \x01(\x05\x12>\n\x07sources\x18\x02 \x03(\x0b\x32-.oak9.tython.k8s.api.core.v1.VolumeProjection\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb0\x01\n\x13QuobyteVolumeSource\x12\r\n\x05group\x18\x01 \x01(\t\x12\x11\n\tread_only\x18\x02 \x01(\x08\x12\x10\n\x08registry\x18\x03 \x01(\t\x12\x0e\n\x06tenant\x18\x04 \x01(\t\x12\x0c\n\x04user\x18\x05 \x01(\t\x12\x0e\n\x06volume\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x88\x02\n\x19RBDPersistentVolumeSource\x12\x0f\n\x07\x66s_type\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x0f\n\x07keyring\x18\x03 \x01(\t\x12\x10\n\x08monitors\x18\x04 \x03(\t\x12\x0c\n\x04pool\x18\x05 \x01(\t\x12\x11\n\tread_only\x18\x06 \x01(\x08\x12@\n\nsecret_ref\x18\x07 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.SecretReference\x12\x0c\n\x04user\x18\x08 \x01(\t\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x83\x02\n\x0fRBDVolumeSource\x12\x0f\n\x07\x66s_type\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x0f\n\x07keyring\x18\x03 \x01(\t\x12\x10\n\x08monitors\x18\x04 \x03(\t\x12\x0c\n\x04pool\x18\x05 \x01(\t\x12\x11\n\tread_only\x18\x06 \x01(\x08\x12\x45\n\nsecret_ref\x18\x07 \x01(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.LocalObjectReference\x12\x0c\n\x04user\x18\x08 \x01(\t\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd0\x02\n\x15ReplicationController\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x44\n\x04spec\x18\x04 \x01(\x0b\x32\x36.oak9.tython.k8s.api.core.v1.ReplicationControllerSpec\x12H\n\x06status\x18\x05 \x01(\x0b\x32\x38.oak9.tython.k8s.api.core.v1.ReplicationControllerStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xeb\x01\n\x1eReplicationControllerCondition\x12Q\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x85\x02\n\x19ReplicationControllerList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x41\n\x05items\x18\x02 \x03(\x0b\x32\x32.oak9.tython.k8s.api.core.v1.ReplicationController\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xca\x02\n\x19ReplicationControllerSpec\x12\x19\n\x11min_ready_seconds\x18\x01 \x01(\x05\x12\x10\n\x08replicas\x18\x02 \x01(\x05\x12V\n\x08selector\x18\x03 \x03(\x0b\x32\x44.oak9.tython.k8s.api.core.v1.ReplicationControllerSpec.SelectorEntry\x12>\n\x08template\x18\x04 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.PodTemplateSpec\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a/\n\rSelectorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xaa\x02\n\x1bReplicationControllerStatus\x12\x1a\n\x12\x61vailable_replicas\x18\x01 \x01(\x05\x12O\n\nconditions\x18\x02 \x03(\x0b\x32;.oak9.tython.k8s.api.core.v1.ReplicationControllerCondition\x12\x1e\n\x16\x66ully_labeled_replicas\x18\x03 \x01(\x05\x12\x1b\n\x13observed_generation\x18\x04 \x01(\x05\x12\x16\n\x0eready_replicas\x18\x05 \x01(\x05\x12\x10\n\x08replicas\x18\x06 \x01(\x05\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"V\n\rResourceClaim\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc4\x01\n\x15ResourceFieldSelector\x12\x16\n\x0e\x63ontainer_name\x18\x01 \x01(\t\x12H\n\x07\x64ivisor\x18\x02 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.api.resource.Quantity\x12\x10\n\x08resource\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb8\x02\n\rResourceQuota\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12<\n\x04spec\x18\x04 \x01(\x0b\x32..oak9.tython.k8s.api.core.v1.ResourceQuotaSpec\x12@\n\x06status\x18\x05 \x01(\x0b\x32\x30.oak9.tython.k8s.api.core.v1.ResourceQuotaStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf5\x01\n\x11ResourceQuotaList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x39\n\x05items\x18\x02 \x03(\x0b\x32*.oak9.tython.k8s.api.core.v1.ResourceQuota\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x95\x02\n\x11ResourceQuotaSpec\x12\x46\n\x04hard\x18\x01 \x03(\x0b\x32\x38.oak9.tython.k8s.api.core.v1.ResourceQuotaSpec.HardEntry\x12\x42\n\x0escope_selector\x18\x02 \x01(\x0b\x32*.oak9.tython.k8s.api.core.v1.ScopeSelector\x12\x0e\n\x06scopes\x18\x03 \x03(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a+\n\tHardEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbc\x02\n\x13ResourceQuotaStatus\x12H\n\x04hard\x18\x01 \x03(\x0b\x32:.oak9.tython.k8s.api.core.v1.ResourceQuotaStatus.HardEntry\x12H\n\x04used\x18\x02 \x03(\x0b\x32:.oak9.tython.k8s.api.core.v1.ResourceQuotaStatus.UsedEntry\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a+\n\tHardEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tUsedEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8d\x03\n\x14ResourceRequirements\x12:\n\x06\x63laims\x18\x01 \x03(\x0b\x32*.oak9.tython.k8s.api.core.v1.ResourceClaim\x12M\n\x06limits\x18\x02 \x03(\x0b\x32=.oak9.tython.k8s.api.core.v1.ResourceRequirements.LimitsEntry\x12Q\n\x08requests\x18\x03 \x03(\x0b\x32?.oak9.tython.k8s.api.core.v1.ResourceRequirements.RequestsEntry\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLimitsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rRequestsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x82\x01\n\x0eSELinuxOptions\x12\r\n\x05level\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0c\n\x04user\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd0\x02\n\x1dScaleIOPersistentVolumeSource\x12\x0f\n\x07\x66s_type\x18\x01 \x01(\t\x12\x0f\n\x07gateway\x18\x02 \x01(\t\x12\x19\n\x11protection_domain\x18\x03 \x01(\t\x12\x11\n\tread_only\x18\x04 \x01(\x08\x12@\n\nsecret_ref\x18\x05 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.SecretReference\x12\x13\n\x0bssl_enabled\x18\x06 \x01(\x08\x12\x14\n\x0cstorage_mode\x18\x07 \x01(\t\x12\x14\n\x0cstorage_pool\x18\x08 \x01(\t\x12\x0e\n\x06system\x18\t \x01(\t\x12\x13\n\x0bvolume_name\x18\n \x01(\t\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xcb\x02\n\x13ScaleIOVolumeSource\x12\x0f\n\x07\x66s_type\x18\x01 \x01(\t\x12\x0f\n\x07gateway\x18\x02 \x01(\t\x12\x19\n\x11protection_domain\x18\x03 \x01(\t\x12\x11\n\tread_only\x18\x04 \x01(\x08\x12\x45\n\nsecret_ref\x18\x05 \x01(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.LocalObjectReference\x12\x13\n\x0bssl_enabled\x18\x06 \x01(\x08\x12\x14\n\x0cstorage_mode\x18\x07 \x01(\t\x12\x14\n\x0cstorage_pool\x18\x08 \x01(\t\x12\x0e\n\x06system\x18\t \x01(\t\x12\x13\n\x0bvolume_name\x18\n \x01(\t\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa3\x01\n\rScopeSelector\x12Y\n\x11match_expressions\x18\x01 \x03(\x0b\x32>.oak9.tython.k8s.api.core.v1.ScopedResourceSelectorRequirement\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x92\x01\n!ScopedResourceSelectorRequirement\x12\x10\n\x08operator\x18\x01 \x01(\t\x12\x12\n\nscope_name\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"r\n\x0eSeccompProfile\x12\x19\n\x11localhost_profile\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb9\x03\n\x06Secret\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12;\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32-.oak9.tython.k8s.api.core.v1.Secret.DataEntry\x12\x11\n\timmutable\x18\x03 \x01(\x08\x12\x0c\n\x04kind\x18\x04 \x01(\t\x12K\n\x08metadata\x18\x05 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12H\n\x0bstring_data\x18\x06 \x03(\x0b\x32\x33.oak9.tython.k8s.api.core.v1.Secret.StringDataEntry\x12\x0c\n\x04type\x18\x07 \x01(\t\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a+\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fStringDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"j\n\x0fSecretEnvSource\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08optional\x18\x02 \x01(\x08\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"y\n\x11SecretKeySelector\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08optional\x18\x03 \x01(\x08\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe7\x01\n\nSecretList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x32\n\x05items\x18\x02 \x03(\x0b\x32#.oak9.tython.k8s.api.core.v1.Secret\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa2\x01\n\x10SecretProjection\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32&.oak9.tython.k8s.api.core.v1.KeyToPath\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08optional\x18\x03 \x01(\x08\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"k\n\x0fSecretReference\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc1\x01\n\x12SecretVolumeSource\x12\x14\n\x0c\x64\x65\x66\x61ult_mode\x18\x01 \x01(\x05\x12\x35\n\x05items\x18\x02 \x03(\x0b\x32&.oak9.tython.k8s.api.core.v1.KeyToPath\x12\x10\n\x08optional\x18\x03 \x01(\x08\x12\x13\n\x0bsecret_name\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa0\x04\n\x0fSecurityContext\x12\"\n\x1a\x61llow_privilege_escalation\x18\x01 \x01(\x08\x12?\n\x0c\x63\x61pabilities\x18\x02 \x01(\x0b\x32).oak9.tython.k8s.api.core.v1.Capabilities\x12\x12\n\nprivileged\x18\x03 \x01(\x08\x12\x12\n\nproc_mount\x18\x04 \x01(\t\x12!\n\x19read_only_root_filesystem\x18\x05 \x01(\x08\x12\x14\n\x0crun_as_group\x18\x06 \x01(\x05\x12\x17\n\x0frun_as_non_root\x18\x07 \x01(\x08\x12\x13\n\x0brun_as_user\x18\x08 \x01(\x05\x12\x45\n\x10se_linux_options\x18\t \x01(\x0b\x32+.oak9.tython.k8s.api.core.v1.SELinuxOptions\x12\x44\n\x0fseccomp_profile\x18\n \x01(\x0b\x32+.oak9.tython.k8s.api.core.v1.SeccompProfile\x12S\n\x0fwindows_options\x18\x0b \x01(\x0b\x32:.oak9.tython.k8s.api.core.v1.WindowsSecurityContextOptions\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa6\x02\n\x07Service\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x36\n\x04spec\x18\x04 \x01(\x0b\x32(.oak9.tython.k8s.api.core.v1.ServiceSpec\x12:\n\x06status\x18\x05 \x01(\x0b\x32*.oak9.tython.k8s.api.core.v1.ServiceStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf0\x02\n\x0eServiceAccount\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\'\n\x1f\x61utomount_service_account_token\x18\x02 \x01(\x08\x12M\n\x12image_pull_secrets\x18\x03 \x03(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.LocalObjectReference\x12\x0c\n\x04kind\x18\x04 \x01(\t\x12K\n\x08metadata\x18\x05 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12=\n\x07secrets\x18\x06 \x03(\x0b\x32,.oak9.tython.k8s.api.core.v1.ObjectReference\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf7\x01\n\x12ServiceAccountList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12:\n\x05items\x18\x02 \x03(\x0b\x32+.oak9.tython.k8s.api.core.v1.ServiceAccount\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x94\x01\n\x1dServiceAccountTokenProjection\x12\x10\n\x08\x61udience\x18\x01 \x01(\t\x12\x1a\n\x12\x65xpiration_seconds\x18\x02 \x01(\x05\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe9\x01\n\x0bServiceList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x33\n\x05items\x18\x02 \x03(\x0b\x32$.oak9.tython.k8s.api.core.v1.Service\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xed\x01\n\x0bServicePort\x12\x14\n\x0c\x61pp_protocol\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tnode_port\x18\x03 \x01(\x05\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12\x10\n\x08protocol\x18\x05 \x01(\t\x12N\n\x0btarget_port\x18\x06 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.util.intstr.IntOrString\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8a\x06\n\x0bServiceSpec\x12)\n!allocate_load_balancer_node_ports\x18\x01 \x01(\x08\x12\x12\n\ncluster_ip\x18\x02 \x01(\t\x12\x13\n\x0b\x63luster_ips\x18\x03 \x03(\t\x12\x14\n\x0c\x65xternal_ips\x18\x04 \x03(\t\x12\x15\n\rexternal_name\x18\x05 \x01(\t\x12\x1f\n\x17\x65xternal_traffic_policy\x18\x06 \x01(\t\x12\x1e\n\x16health_check_node_port\x18\x07 \x01(\x05\x12\x1f\n\x17internal_traffic_policy\x18\x08 \x01(\t\x12\x13\n\x0bip_families\x18\t \x03(\t\x12\x18\n\x10ip_family_policy\x18\n \x01(\t\x12\x1b\n\x13load_balancer_class\x18\x0b \x01(\t\x12\x18\n\x10load_balancer_ip\x18\x0c \x01(\t\x12#\n\x1bload_balancer_source_ranges\x18\r \x03(\t\x12\x37\n\x05ports\x18\x0e \x03(\x0b\x32(.oak9.tython.k8s.api.core.v1.ServicePort\x12#\n\x1bpublish_not_ready_addresses\x18\x0f \x01(\x08\x12H\n\x08selector\x18\x10 \x03(\x0b\x32\x36.oak9.tython.k8s.api.core.v1.ServiceSpec.SelectorEntry\x12\x18\n\x10session_affinity\x18\x11 \x01(\t\x12S\n\x17session_affinity_config\x18\x12 \x01(\x0b\x32\x32.oak9.tython.k8s.api.core.v1.SessionAffinityConfig\x12\x0c\n\x04type\x18\x13 \x01(\t\x12\x37\n\rresource_info\x18\x14 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a/\n\rSelectorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xde\x01\n\rServiceStatus\x12L\n\nconditions\x18\x01 \x03(\x0b\x32\x38.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Condition\x12\x46\n\rload_balancer\x18\x02 \x01(\x0b\x32/.oak9.tython.k8s.api.core.v1.LoadBalancerStatus\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x90\x01\n\x15SessionAffinityConfig\x12>\n\tclient_ip\x18\x01 \x01(\x0b\x32+.oak9.tython.k8s.api.core.v1.ClientIPConfig\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xef\x01\n\x1fStorageOSPersistentVolumeSource\x12\x0f\n\x07\x66s_type\x18\x01 \x01(\t\x12\x11\n\tread_only\x18\x02 \x01(\x08\x12@\n\nsecret_ref\x18\x03 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.ObjectReference\x12\x13\n\x0bvolume_name\x18\x04 \x01(\t\x12\x18\n\x10volume_namespace\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xea\x01\n\x15StorageOSVolumeSource\x12\x0f\n\x07\x66s_type\x18\x01 \x01(\t\x12\x11\n\tread_only\x18\x02 \x01(\x08\x12\x45\n\nsecret_ref\x18\x03 \x01(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.LocalObjectReference\x12\x13\n\x0bvolume_name\x18\x04 \x01(\t\x12\x18\n\x10volume_namespace\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"^\n\x06Sysctl\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa1\x01\n\x0fTCPSocketAction\x12\x0c\n\x04host\x18\x01 \x01(\t\x12G\n\x04port\x18\x02 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.util.intstr.IntOrString\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb5\x01\n\x05Taint\x12\x0e\n\x06\x65\x66\x66\x65\x63t\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12G\n\ntime_added\x18\x03 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\r\n\x05value\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9f\x01\n\nToleration\x12\x0e\n\x06\x65\x66\x66\x65\x63t\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x10\n\x08operator\x18\x03 \x01(\t\x12\x1a\n\x12toleration_seconds\x18\x04 \x01(\x05\x12\r\n\x05value\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"x\n TopologySelectorLabelRequirement\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xaf\x01\n\x14TopologySelectorTerm\x12^\n\x17match_label_expressions\x18\x01 \x03(\x0b\x32=.oak9.tython.k8s.api.core.v1.TopologySelectorLabelRequirement\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd6\x02\n\x18TopologySpreadConstraint\x12T\n\x0elabel_selector\x18\x01 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x18\n\x10match_label_keys\x18\x02 \x03(\t\x12\x10\n\x08max_skew\x18\x03 \x01(\x05\x12\x13\n\x0bmin_domains\x18\x04 \x01(\x05\x12\x1c\n\x14node_affinity_policy\x18\x05 \x01(\t\x12\x1a\n\x12node_taints_policy\x18\x06 \x01(\t\x12\x14\n\x0ctopology_key\x18\x07 \x01(\t\x12\x1a\n\x12when_unsatisfiable\x18\x08 \x01(\t\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x83\x01\n\x19TypedLocalObjectReference\x12\x11\n\tapi_group\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x91\x01\n\x14TypedObjectReference\x12\x11\n\tapi_group\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tnamespace\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf5\x10\n\x06Volume\x12^\n\x17\x61ws_elastic_block_store\x18\x01 \x01(\x0b\x32=.oak9.tython.k8s.api.core.v1.AWSElasticBlockStoreVolumeSource\x12\x46\n\nazure_disk\x18\x02 \x01(\x0b\x32\x32.oak9.tython.k8s.api.core.v1.AzureDiskVolumeSource\x12\x46\n\nazure_file\x18\x03 \x01(\x0b\x32\x32.oak9.tython.k8s.api.core.v1.AzureFileVolumeSource\x12?\n\x06\x63\x65phfs\x18\x04 \x01(\x0b\x32/.oak9.tython.k8s.api.core.v1.CephFSVolumeSource\x12?\n\x06\x63inder\x18\x05 \x01(\x0b\x32/.oak9.tython.k8s.api.core.v1.CinderVolumeSource\x12\x46\n\nconfig_map\x18\x06 \x01(\x0b\x32\x32.oak9.tython.k8s.api.core.v1.ConfigMapVolumeSource\x12\x39\n\x03\x63si\x18\x07 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.CSIVolumeSource\x12L\n\x0e\x64ownward_a_p_i\x18\x08 \x01(\x0b\x32\x34.oak9.tython.k8s.api.core.v1.DownwardAPIVolumeSource\x12\x44\n\tempty_dir\x18\t \x01(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.EmptyDirVolumeSource\x12\x45\n\tephemeral\x18\n \x01(\x0b\x32\x32.oak9.tython.k8s.api.core.v1.EphemeralVolumeSource\x12\x37\n\x02\x66\x63\x18\x0b \x01(\x0b\x32+.oak9.tython.k8s.api.core.v1.FCVolumeSource\x12\x42\n\x0b\x66lex_volume\x18\x0c \x01(\x0b\x32-.oak9.tython.k8s.api.core.v1.FlexVolumeSource\x12\x41\n\x07\x66locker\x18\r \x01(\x0b\x32\x30.oak9.tython.k8s.api.core.v1.FlockerVolumeSource\x12W\n\x13gce_persistent_disk\x18\x0e \x01(\x0b\x32:.oak9.tython.k8s.api.core.v1.GCEPersistentDiskVolumeSource\x12\x42\n\x08git_repo\x18\x0f \x01(\x0b\x32\x30.oak9.tython.k8s.api.core.v1.GitRepoVolumeSource\x12\x45\n\tglusterfs\x18\x10 \x01(\x0b\x32\x32.oak9.tython.k8s.api.core.v1.GlusterfsVolumeSource\x12\x44\n\thost_path\x18\x11 \x01(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.HostPathVolumeSource\x12=\n\x05iscsi\x18\x12 \x01(\x0b\x32..oak9.tython.k8s.api.core.v1.ISCSIVolumeSource\x12\x0c\n\x04name\x18\x13 \x01(\t\x12\x39\n\x03nfs\x18\x14 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.NFSVolumeSource\x12_\n\x17persistent_volume_claim\x18\x15 \x01(\x0b\x32>.oak9.tython.k8s.api.core.v1.PersistentVolumeClaimVolumeSource\x12]\n\x16photon_persistent_disk\x18\x16 \x01(\x0b\x32=.oak9.tython.k8s.api.core.v1.PhotonPersistentDiskVolumeSource\x12J\n\x0fportworx_volume\x18\x17 \x01(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.PortworxVolumeSource\x12\x45\n\tprojected\x18\x18 \x01(\x0b\x32\x32.oak9.tython.k8s.api.core.v1.ProjectedVolumeSource\x12\x41\n\x07quobyte\x18\x19 \x01(\x0b\x32\x30.oak9.tython.k8s.api.core.v1.QuobyteVolumeSource\x12\x39\n\x03rbd\x18\x1a \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.RBDVolumeSource\x12\x42\n\x08scale_io\x18\x1b \x01(\x0b\x32\x30.oak9.tython.k8s.api.core.v1.ScaleIOVolumeSource\x12?\n\x06secret\x18\x1c \x01(\x0b\x32/.oak9.tython.k8s.api.core.v1.SecretVolumeSource\x12\x45\n\tstorageos\x18\x1d \x01(\x0b\x32\x32.oak9.tython.k8s.api.core.v1.StorageOSVolumeSource\x12S\n\x0evsphere_volume\x18\x1e \x01(\x0b\x32;.oak9.tython.k8s.api.core.v1.VsphereVirtualDiskVolumeSource\x12\x37\n\rresource_info\x18\x1f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"j\n\x0cVolumeDevice\x12\x13\n\x0b\x64\x65vice_path\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbf\x01\n\x0bVolumeMount\x12\x12\n\nmount_path\x18\x01 \x01(\t\x12\x19\n\x11mount_propagation\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tread_only\x18\x04 \x01(\x08\x12\x10\n\x08sub_path\x18\x05 \x01(\t\x12\x15\n\rsub_path_expr\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8a\x01\n\x12VolumeNodeAffinity\x12;\n\x08required\x18\x01 \x01(\x0b\x32).oak9.tython.k8s.api.core.v1.NodeSelector\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf7\x02\n\x10VolumeProjection\x12\x44\n\nconfig_map\x18\x01 \x01(\x0b\x32\x30.oak9.tython.k8s.api.core.v1.ConfigMapProjection\x12J\n\x0e\x64ownward_a_p_i\x18\x02 \x01(\x0b\x32\x32.oak9.tython.k8s.api.core.v1.DownwardAPIProjection\x12=\n\x06secret\x18\x03 \x01(\x0b\x32-.oak9.tython.k8s.api.core.v1.SecretProjection\x12Y\n\x15service_account_token\x18\x04 \x01(\x0b\x32:.oak9.tython.k8s.api.core.v1.ServiceAccountTokenProjection\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb7\x01\n\x1eVsphereVirtualDiskVolumeSource\x12\x0f\n\x07\x66s_type\x18\x01 \x01(\t\x12\x19\n\x11storage_policy_id\x18\x02 \x01(\t\x12\x1b\n\x13storage_policy_name\x18\x03 \x01(\t\x12\x13\n\x0bvolume_path\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xab\x01\n\x17WeightedPodAffinityTerm\x12G\n\x11pod_affinity_term\x18\x01 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.PodAffinityTerm\x12\x0e\n\x06weight\x18\x02 \x01(\x05\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc9\x01\n\x1dWindowsSecurityContextOptions\x12\x1c\n\x14gmsa_credential_spec\x18\x01 \x01(\t\x12!\n\x19gmsa_credential_spec_name\x18\x02 \x01(\t\x12\x14\n\x0chost_process\x18\x03 \x01(\x08\x12\x18\n\x10run_as_user_name\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.core.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CSIPERSISTENTVOLUMESOURCE_VOLUMEATTRIBUTESENTRY._options = None
  _CSIPERSISTENTVOLUMESOURCE_VOLUMEATTRIBUTESENTRY._serialized_options = b'8\001'
  _CSIVOLUMESOURCE_VOLUMEATTRIBUTESENTRY._options = None
  _CSIVOLUMESOURCE_VOLUMEATTRIBUTESENTRY._serialized_options = b'8\001'
  _CONFIGMAP_BINARYDATAENTRY._options = None
  _CONFIGMAP_BINARYDATAENTRY._serialized_options = b'8\001'
  _CONFIGMAP_DATAENTRY._options = None
  _CONFIGMAP_DATAENTRY._serialized_options = b'8\001'
  _FLEXPERSISTENTVOLUMESOURCE_OPTIONSENTRY._options = None
  _FLEXPERSISTENTVOLUMESOURCE_OPTIONSENTRY._serialized_options = b'8\001'
  _FLEXVOLUMESOURCE_OPTIONSENTRY._options = None
  _FLEXVOLUMESOURCE_OPTIONSENTRY._serialized_options = b'8\001'
  _LIMITRANGEITEM_DEFAULTENTRY._options = None
  _LIMITRANGEITEM_DEFAULTENTRY._serialized_options = b'8\001'
  _LIMITRANGEITEM_DEFAULTREQUESTENTRY._options = None
  _LIMITRANGEITEM_DEFAULTREQUESTENTRY._serialized_options = b'8\001'
  _LIMITRANGEITEM_MAXENTRY._options = None
  _LIMITRANGEITEM_MAXENTRY._serialized_options = b'8\001'
  _LIMITRANGEITEM_MAXLIMITREQUESTRATIOENTRY._options = None
  _LIMITRANGEITEM_MAXLIMITREQUESTRATIOENTRY._serialized_options = b'8\001'
  _LIMITRANGEITEM_MINENTRY._options = None
  _LIMITRANGEITEM_MINENTRY._serialized_options = b'8\001'
  _NODESTATUS_ALLOCATABLEENTRY._options = None
  _NODESTATUS_ALLOCATABLEENTRY._serialized_options = b'8\001'
  _NODESTATUS_CAPACITYENTRY._options = None
  _NODESTATUS_CAPACITYENTRY._serialized_options = b'8\001'
  _PERSISTENTVOLUMECLAIMSTATUS_ALLOCATEDRESOURCESENTRY._options = None
  _PERSISTENTVOLUMECLAIMSTATUS_ALLOCATEDRESOURCESENTRY._serialized_options = b'8\001'
  _PERSISTENTVOLUMECLAIMSTATUS_CAPACITYENTRY._options = None
  _PERSISTENTVOLUMECLAIMSTATUS_CAPACITYENTRY._serialized_options = b'8\001'
  _PERSISTENTVOLUMESPEC_CAPACITYENTRY._options = None
  _PERSISTENTVOLUMESPEC_CAPACITYENTRY._serialized_options = b'8\001'
  _PODSPEC_NODESELECTORENTRY._options = None
  _PODSPEC_NODESELECTORENTRY._serialized_options = b'8\001'
  _PODSPEC_OVERHEADENTRY._options = None
  _PODSPEC_OVERHEADENTRY._serialized_options = b'8\001'
  _REPLICATIONCONTROLLERSPEC_SELECTORENTRY._options = None
  _REPLICATIONCONTROLLERSPEC_SELECTORENTRY._serialized_options = b'8\001'
  _RESOURCEQUOTASPEC_HARDENTRY._options = None
  _RESOURCEQUOTASPEC_HARDENTRY._serialized_options = b'8\001'
  _RESOURCEQUOTASTATUS_HARDENTRY._options = None
  _RESOURCEQUOTASTATUS_HARDENTRY._serialized_options = b'8\001'
  _RESOURCEQUOTASTATUS_USEDENTRY._options = None
  _RESOURCEQUOTASTATUS_USEDENTRY._serialized_options = b'8\001'
  _RESOURCEREQUIREMENTS_LIMITSENTRY._options = None
  _RESOURCEREQUIREMENTS_LIMITSENTRY._serialized_options = b'8\001'
  _RESOURCEREQUIREMENTS_REQUESTSENTRY._options = None
  _RESOURCEREQUIREMENTS_REQUESTSENTRY._serialized_options = b'8\001'
  _SECRET_DATAENTRY._options = None
  _SECRET_DATAENTRY._serialized_options = b'8\001'
  _SECRET_STRINGDATAENTRY._options = None
  _SECRET_STRINGDATAENTRY._serialized_options = b'8\001'
  _SERVICESPEC_SELECTORENTRY._options = None
  _SERVICESPEC_SELECTORENTRY._serialized_options = b'8\001'
  _AWSELASTICBLOCKSTOREVOLUMESOURCE._serialized_start=298
  _AWSELASTICBLOCKSTOREVOLUMESOURCE._serialized_end=463
  _AFFINITY._serialized_start=466
  _AFFINITY._serialized_end=736
  _ATTACHEDVOLUME._serialized_start=738
  _ATTACHEDVOLUME._serialized_end=846
  _AZUREDISKVOLUMESOURCE._serialized_start=849
  _AZUREDISKVOLUMESOURCE._serialized_end=1040
  _AZUREFILEPERSISTENTVOLUMESOURCE._serialized_start=1043
  _AZUREFILEPERSISTENTVOLUMESOURCE._serialized_end=1219
  _AZUREFILEVOLUMESOURCE._serialized_start=1222
  _AZUREFILEVOLUMESOURCE._serialized_end=1362
  _BINDING._serialized_start=1365
  _BINDING._serialized_end=1605
  _CSIPERSISTENTVOLUMESOURCE._serialized_start=1608
  _CSIPERSISTENTVOLUMESOURCE._serialized_end=2332
  _CSIPERSISTENTVOLUMESOURCE_VOLUMEATTRIBUTESENTRY._serialized_start=2277
  _CSIPERSISTENTVOLUMESOURCE_VOLUMEATTRIBUTESENTRY._serialized_end=2332
  _CSIVOLUMESOURCE._serialized_start=2335
  _CSIVOLUMESOURCE._serialized_end=2697
  _CSIVOLUMESOURCE_VOLUMEATTRIBUTESENTRY._serialized_start=2277
  _CSIVOLUMESOURCE_VOLUMEATTRIBUTESENTRY._serialized_end=2332
  _CAPABILITIES._serialized_start=2699
  _CAPABILITIES._serialized_end=2797
  _CEPHFSPERSISTENTVOLUMESOURCE._serialized_start=2800
  _CEPHFSPERSISTENTVOLUMESOURCE._serialized_end=3039
  _CEPHFSVOLUMESOURCE._serialized_start=3042
  _CEPHFSVOLUMESOURCE._serialized_end=3276
  _CINDERPERSISTENTVOLUMESOURCE._serialized_start=3279
  _CINDERPERSISTENTVOLUMESOURCE._serialized_end=3487
  _CINDERVOLUMESOURCE._serialized_start=3490
  _CINDERVOLUMESOURCE._serialized_end=3693
  _CLAIMSOURCE._serialized_start=3696
  _CLAIMSOURCE._serialized_end=3833
  _CLIENTIPCONFIG._serialized_start=3835
  _CLIENTIPCONFIG._serialized_end=3933
  _COMPONENTCONDITION._serialized_start=3936
  _COMPONENTCONDITION._serialized_end=4075
  _COMPONENTSTATUS._serialized_start=4078
  _COMPONENTSTATUS._serialized_end=4333
  _COMPONENTSTATUSLIST._serialized_start=4336
  _COMPONENTSTATUSLIST._serialized_end=4585
  _CONFIGMAP._serialized_start=4588
  _CONFIGMAP._serialized_end=5024
  _CONFIGMAP_BINARYDATAENTRY._serialized_start=4930
  _CONFIGMAP_BINARYDATAENTRY._serialized_end=4979
  _CONFIGMAP_DATAENTRY._serialized_start=4981
  _CONFIGMAP_DATAENTRY._serialized_end=5024
  _CONFIGMAPENVSOURCE._serialized_start=5026
  _CONFIGMAPENVSOURCE._serialized_end=5135
  _CONFIGMAPKEYSELECTOR._serialized_start=5137
  _CONFIGMAPKEYSELECTOR._serialized_end=5261
  _CONFIGMAPLIST._serialized_start=5264
  _CONFIGMAPLIST._serialized_end=5501
  _CONFIGMAPNODECONFIGSOURCE._serialized_start=5504
  _CONFIGMAPNODECONFIGSOURCE._serialized_end=5688
  _CONFIGMAPPROJECTION._serialized_start=5691
  _CONFIGMAPPROJECTION._serialized_end=5856
  _CONFIGMAPVOLUMESOURCE._serialized_start=5859
  _CONFIGMAPVOLUMESOURCE._serialized_end=6048
  _CONTAINER._serialized_start=6051
  _CONTAINER._serialized_end=7029
  _CONTAINERIMAGE._serialized_start=7031
  _CONTAINERIMAGE._serialized_end=7139
  _CONTAINERPORT._serialized_start=7142
  _CONTAINERPORT._serialized_end=7306
  _CONTAINERSTATE._serialized_start=7309
  _CONTAINERSTATE._serialized_end=7595
  _CONTAINERSTATERUNNING._serialized_start=7598
  _CONTAINERSTATERUNNING._serialized_end=7751
  _CONTAINERSTATETERMINATED._serialized_start=7754
  _CONTAINERSTATETERMINATED._serialized_end=8074
  _CONTAINERSTATEWAITING._serialized_start=8076
  _CONTAINERSTATEWAITING._serialized_end=8189
  _CONTAINERSTATUS._serialized_start=8192
  _CONTAINERSTATUS._serialized_end=8515
  _DAEMONENDPOINT._serialized_start=8517
  _DAEMONENDPOINT._serialized_end=8604
  _DOWNWARDAPIPROJECTION._serialized_start=8607
  _DOWNWARDAPIPROJECTION._serialized_end=8754
  _DOWNWARDAPIVOLUMEFILE._serialized_start=8757
  _DOWNWARDAPIVOLUMEFILE._serialized_end=9014
  _DOWNWARDAPIVOLUMESOURCE._serialized_start=9017
  _DOWNWARDAPIVOLUMESOURCE._serialized_end=9188
  _EMPTYDIRVOLUMESOURCE._serialized_start=9191
  _EMPTYDIRVOLUMESOURCE._serialized_end=9363
  _ENDPOINTADDRESS._serialized_start=9366
  _ENDPOINTADDRESS._serialized_end=9555
  _ENDPOINTPORT._serialized_start=9558
  _ENDPOINTPORT._serialized_end=9697
  _ENDPOINTSUBSET._serialized_start=9700
  _ENDPOINTSUBSET._serialized_end=9971
  _ENDPOINTS._serialized_start=9974
  _ENDPOINTS._serialized_end=10216
  _ENDPOINTSLIST._serialized_start=10219
  _ENDPOINTSLIST._serialized_end=10456
  _ENVFROMSOURCE._serialized_start=10459
  _ENVFROMSOURCE._serialized_end=10686
  _ENVVAR._serialized_start=10689
  _ENVVAR._serialized_end=10846
  _ENVVARSOURCE._serialized_start=10849
  _ENVVARSOURCE._serialized_end=11220
  _EPHEMERALCONTAINER._serialized_start=11223
  _EPHEMERALCONTAINER._serialized_end=12241
  _EPHEMERALVOLUMESOURCE._serialized_start=12244
  _EPHEMERALVOLUMESOURCE._serialized_end=12415
  _EVENT._serialized_start=12418
  _EVENT._serialized_end=13212
  _EVENTLIST._serialized_start=13215
  _EVENTLIST._serialized_end=13444
  _EVENTSERIES._serialized_start=13447
  _EVENTSERIES._serialized_end=13618
  _EVENTSOURCE._serialized_start=13620
  _EVENTSOURCE._serialized_end=13723
  _EXECACTION._serialized_start=13725
  _EXECACTION._serialized_end=13811
  _FCVOLUMESOURCE._serialized_start=13814
  _FCVOLUMESOURCE._serialized_end=13974
  _FLEXPERSISTENTVOLUMESOURCE._serialized_start=13977
  _FLEXPERSISTENTVOLUMESOURCE._serialized_end=14315
  _FLEXPERSISTENTVOLUMESOURCE_OPTIONSENTRY._serialized_start=14269
  _FLEXPERSISTENTVOLUMESOURCE_OPTIONSENTRY._serialized_end=14315
  _FLEXVOLUMESOURCE._serialized_start=14318
  _FLEXVOLUMESOURCE._serialized_end=14641
  _FLEXVOLUMESOURCE_OPTIONSENTRY._serialized_start=14269
  _FLEXVOLUMESOURCE_OPTIONSENTRY._serialized_end=14315
  _FLOCKERVOLUMESOURCE._serialized_start=14643
  _FLOCKERVOLUMESOURCE._serialized_end=14767
  _GCEPERSISTENTDISKVOLUMESOURCE._serialized_start=14770
  _GCEPERSISTENTDISKVOLUMESOURCE._serialized_end=14930
  _GRPCACTION._serialized_start=14932
  _GRPCACTION._serialized_end=15032
  _GITREPOVOLUMESOURCE._serialized_start=15035
  _GITREPOVOLUMESOURCE._serialized_end=15170
  _GLUSTERFSPERSISTENTVOLUMESOURCE._serialized_start=15173
  _GLUSTERFSPERSISTENTVOLUMESOURCE._serialized_end=15344
  _GLUSTERFSVOLUMESOURCE._serialized_start=15347
  _GLUSTERFSVOLUMESOURCE._serialized_end=15479
  _HTTPGETACTION._serialized_start=15482
  _HTTPGETACTION._serialized_end=15734
  _HTTPHEADER._serialized_start=15736
  _HTTPHEADER._serialized_end=15834
  _HOSTALIAS._serialized_start=15836
  _HOSTALIAS._serialized_end=15935
  _HOSTPATHVOLUMESOURCE._serialized_start=15937
  _HOSTPATHVOLUMESOURCE._serialized_end=16044
  _ISCSIPERSISTENTVOLUMESOURCE._serialized_start=16047
  _ISCSIPERSISTENTVOLUMESOURCE._serialized_end=16406
  _ISCSIVOLUMESOURCE._serialized_start=16409
  _ISCSIVOLUMESOURCE._serialized_end=16763
  _KEYTOPATH._serialized_start=16765
  _KEYTOPATH._serialized_end=16874
  _LIFECYCLE._serialized_start=16877
  _LIFECYCLE._serialized_end=17077
  _LIFECYCLEHANDLER._serialized_start=17080
  _LIFECYCLEHANDLER._serialized_end=17338
  _LIMITRANGE._serialized_start=17341
  _LIMITRANGE._serialized_end=17581
  _LIMITRANGEITEM._serialized_start=17584
  _LIMITRANGEITEM._serialized_end=18326
  _LIMITRANGEITEM_DEFAULTENTRY._serialized_start=18076
  _LIMITRANGEITEM_DEFAULTENTRY._serialized_end=18122
  _LIMITRANGEITEM_DEFAULTREQUESTENTRY._serialized_start=18124
  _LIMITRANGEITEM_DEFAULTREQUESTENTRY._serialized_end=18177
  _LIMITRANGEITEM_MAXENTRY._serialized_start=18179
  _LIMITRANGEITEM_MAXENTRY._serialized_end=18221
  _LIMITRANGEITEM_MAXLIMITREQUESTRATIOENTRY._serialized_start=18223
  _LIMITRANGEITEM_MAXLIMITREQUESTRATIOENTRY._serialized_end=18282
  _LIMITRANGEITEM_MINENTRY._serialized_start=18284
  _LIMITRANGEITEM_MINENTRY._serialized_end=18326
  _LIMITRANGELIST._serialized_start=18329
  _LIMITRANGELIST._serialized_end=18568
  _LIMITRANGESPEC._serialized_start=18571
  _LIMITRANGESPEC._serialized_end=18705
  _LOADBALANCERINGRESS._serialized_start=18708
  _LOADBALANCERINGRESS._serialized_end=18872
  _LOADBALANCERSTATUS._serialized_start=18875
  _LOADBALANCERSTATUS._serialized_end=19019
  _LOCALOBJECTREFERENCE._serialized_start=19021
  _LOCALOBJECTREFERENCE._serialized_end=19114
  _LOCALVOLUMESOURCE._serialized_start=19116
  _LOCALVOLUMESOURCE._serialized_end=19223
  _NFSVOLUMESOURCE._serialized_start=19225
  _NFSVOLUMESOURCE._serialized_end=19348
  _NAMESPACE._serialized_start=19351
  _NAMESPACE._serialized_end=19651
  _NAMESPACECONDITION._serialized_start=19654
  _NAMESPACECONDITION._serialized_end=19877
  _NAMESPACELIST._serialized_start=19880
  _NAMESPACELIST._serialized_end=20117
  _NAMESPACESPEC._serialized_start=20119
  _NAMESPACESPEC._serialized_end=20211
  _NAMESPACESTATUS._serialized_start=20214
  _NAMESPACESTATUS._serialized_end=20372
  _NODE._serialized_start=20375
  _NODE._serialized_end=20660
  _NODEADDRESS._serialized_start=20662
  _NODEADDRESS._serialized_end=20763
  _NODEAFFINITY._serialized_start=20766
  _NODEAFFINITY._serialized_end=21057
  _NODECONDITION._serialized_start=21060
  _NODECONDITION._serialized_end=21360
  _NODECONFIGSOURCE._serialized_start=21363
  _NODECONFIGSOURCE._serialized_end=21514
  _NODECONFIGSTATUS._serialized_start=21517
  _NODECONFIGSTATUS._serialized_end=21807
  _NODEDAEMONENDPOINTS._serialized_start=21810
  _NODEDAEMONENDPOINTS._serialized_end=21959
  _NODELIST._serialized_start=21962
  _NODELIST._serialized_end=22189
  _NODESELECTOR._serialized_start=22192
  _NODESELECTOR._serialized_end=22339
  _NODESELECTORREQUIREMENT._serialized_start=22342
  _NODESELECTORREQUIREMENT._serialized_end=22471
  _NODESELECTORTERM._serialized_start=22474
  _NODESELECTORTERM._serialized_end=22706
  _NODESPEC._serialized_start=22709
  _NODESPEC._serialized_end=23000
  _NODESTATUS._serialized_start=23003
  _NODESTATUS._serialized_end=23824
  _NODESTATUS_ALLOCATABLEENTRY._serialized_start=23725
  _NODESTATUS_ALLOCATABLEENTRY._serialized_end=23775
  _NODESTATUS_CAPACITYENTRY._serialized_start=23777
  _NODESTATUS_CAPACITYENTRY._serialized_end=23824
  _NODESYSTEMINFO._serialized_start=23827
  _NODESYSTEMINFO._serialized_end=24138
  _OBJECTFIELDSELECTOR._serialized_start=24140
  _OBJECTFIELDSELECTOR._serialized_end=24259
  _OBJECTREFERENCE._serialized_start=24262
  _OBJECTREFERENCE._serialized_end=24463
  _PERSISTENTVOLUME._serialized_start=24466
  _PERSISTENTVOLUME._serialized_end=24787
  _PERSISTENTVOLUMECLAIM._serialized_start=24790
  _PERSISTENTVOLUMECLAIM._serialized_end=25126
  _PERSISTENTVOLUMECLAIMCONDITION._serialized_start=25129
  _PERSISTENTVOLUMECLAIMCONDITION._serialized_end=25442
  _PERSISTENTVOLUMECLAIMLIST._serialized_start=25445
  _PERSISTENTVOLUMECLAIMLIST._serialized_end=25706
  _PERSISTENTVOLUMECLAIMSPEC._serialized_start=25709
  _PERSISTENTVOLUMECLAIMSPEC._serialized_end=26188
  _PERSISTENTVOLUMECLAIMSTATUS._serialized_start=26191
  _PERSISTENTVOLUMECLAIMSTATUS._serialized_end=26727
  _PERSISTENTVOLUMECLAIMSTATUS_ALLOCATEDRESOURCESENTRY._serialized_start=26621
  _PERSISTENTVOLUMECLAIMSTATUS_ALLOCATEDRESOURCESENTRY._serialized_end=26678
  _PERSISTENTVOLUMECLAIMSTATUS_CAPACITYENTRY._serialized_start=23777
  _PERSISTENTVOLUMECLAIMSTATUS_CAPACITYENTRY._serialized_end=23824
  _PERSISTENTVOLUMECLAIMTEMPLATE._serialized_start=26730
  _PERSISTENTVOLUMECLAIMTEMPLATE._serialized_end=26965
  _PERSISTENTVOLUMECLAIMVOLUMESOURCE._serialized_start=26968
  _PERSISTENTVOLUMECLAIMVOLUMESOURCE._serialized_end=27099
  _PERSISTENTVOLUMELIST._serialized_start=27102
  _PERSISTENTVOLUMELIST._serialized_end=27353
  _PERSISTENTVOLUMESPEC._serialized_start=27356
  _PERSISTENTVOLUMESPEC._serialized_end=29497
  _PERSISTENTVOLUMESPEC_CAPACITYENTRY._serialized_start=23777
  _PERSISTENTVOLUMESPEC_CAPACITYENTRY._serialized_end=23824
  _PERSISTENTVOLUMESTATUS._serialized_start=29500
  _PERSISTENTVOLUMESTATUS._serialized_end=29629
  _PHOTONPERSISTENTDISKVOLUMESOURCE._serialized_start=29631
  _PHOTONPERSISTENTDISKVOLUMESOURCE._serialized_end=29754
  _POD._serialized_start=29757
  _POD._serialized_end=30039
  _PODAFFINITY._serialized_start=30042
  _PODAFFINITY._serialized_end=30335
  _PODAFFINITYTERM._serialized_start=30338
  _PODAFFINITYTERM._serialized_end=30630
  _PODANTIAFFINITY._serialized_start=30633
  _PODANTIAFFINITY._serialized_end=30930
  _PODCONDITION._serialized_start=30933
  _PODCONDITION._serialized_end=31228
  _PODDNSCONFIG._serialized_start=31231
  _PODDNSCONFIG._serialized_end=31407
  _PODDNSCONFIGOPTION._serialized_start=31409
  _PODDNSCONFIGOPTION._serialized_end=31515
  _PODIP._serialized_start=31517
  _PODIP._serialized_end=31593
  _PODLIST._serialized_start=31596
  _PODLIST._serialized_end=31821
  _PODOS._serialized_start=31823
  _PODOS._serialized_end=31901
  _PODREADINESSGATE._serialized_start=31903
  _PODREADINESSGATE._serialized_end=32002
  _PODRESOURCECLAIM._serialized_start=32005
  _PODRESOURCECLAIM._serialized_end=32152
  _PODSCHEDULINGGATE._serialized_start=32154
  _PODSCHEDULINGGATE._serialized_end=32244
  _PODSECURITYCONTEXT._serialized_start=32247
  _PODSECURITYCONTEXT._serialized_end=32751
  _PODSPEC._serialized_start=32754
  _PODSPEC._serialized_end=34655
  _PODSPEC_NODESELECTORENTRY._serialized_start=34555
  _PODSPEC_NODESELECTORENTRY._serialized_end=34606
  _PODSPEC_OVERHEADENTRY._serialized_start=34608
  _PODSPEC_OVERHEADENTRY._serialized_end=34655
  _PODSTATUS._serialized_start=34658
  _PODSTATUS._serialized_end=35281
  _PODTEMPLATE._serialized_start=35284
  _PODTEMPLATE._serialized_end=35530
  _PODTEMPLATELIST._serialized_start=35533
  _PODTEMPLATELIST._serialized_end=35774
  _PODTEMPLATESPEC._serialized_start=35777
  _PODTEMPLATESPEC._serialized_end=35980
  _PORTSTATUS._serialized_start=35982
  _PORTSTATUS._serialized_end=36098
  _PORTWORXVOLUMESOURCE._serialized_start=36101
  _PORTWORXVOLUMESOURCE._serialized_end=36235
  _PREFERREDSCHEDULINGTERM._serialized_start=36238
  _PREFERREDSCHEDULINGTERM._serialized_end=36403
  _PROBE._serialized_start=36406
  _PROBE._serialized_end=36884
  _PROJECTEDVOLUMESOURCE._serialized_start=36887
  _PROJECTEDVOLUMESOURCE._serialized_end=37053
  _QUOBYTEVOLUMESOURCE._serialized_start=37056
  _QUOBYTEVOLUMESOURCE._serialized_end=37232
  _RBDPERSISTENTVOLUMESOURCE._serialized_start=37235
  _RBDPERSISTENTVOLUMESOURCE._serialized_end=37499
  _RBDVOLUMESOURCE._serialized_start=37502
  _RBDVOLUMESOURCE._serialized_end=37761
  _REPLICATIONCONTROLLER._serialized_start=37764
  _REPLICATIONCONTROLLER._serialized_end=38100
  _REPLICATIONCONTROLLERCONDITION._serialized_start=38103
  _REPLICATIONCONTROLLERCONDITION._serialized_end=38338
  _REPLICATIONCONTROLLERLIST._serialized_start=38341
  _REPLICATIONCONTROLLERLIST._serialized_end=38602
  _REPLICATIONCONTROLLERSPEC._serialized_start=38605
  _REPLICATIONCONTROLLERSPEC._serialized_end=38935
  _REPLICATIONCONTROLLERSPEC_SELECTORENTRY._serialized_start=38888
  _REPLICATIONCONTROLLERSPEC_SELECTORENTRY._serialized_end=38935
  _REPLICATIONCONTROLLERSTATUS._serialized_start=38938
  _REPLICATIONCONTROLLERSTATUS._serialized_end=39236
  _RESOURCECLAIM._serialized_start=39238
  _RESOURCECLAIM._serialized_end=39324
  _RESOURCEFIELDSELECTOR._serialized_start=39327
  _RESOURCEFIELDSELECTOR._serialized_end=39523
  _RESOURCEQUOTA._serialized_start=39526
  _RESOURCEQUOTA._serialized_end=39838
  _RESOURCEQUOTALIST._serialized_start=39841
  _RESOURCEQUOTALIST._serialized_end=40086
  _RESOURCEQUOTASPEC._serialized_start=40089
  _RESOURCEQUOTASPEC._serialized_end=40366
  _RESOURCEQUOTASPEC_HARDENTRY._serialized_start=40323
  _RESOURCEQUOTASPEC_HARDENTRY._serialized_end=40366
  _RESOURCEQUOTASTATUS._serialized_start=40369
  _RESOURCEQUOTASTATUS._serialized_end=40685
  _RESOURCEQUOTASTATUS_HARDENTRY._serialized_start=40323
  _RESOURCEQUOTASTATUS_HARDENTRY._serialized_end=40366
  _RESOURCEQUOTASTATUS_USEDENTRY._serialized_start=40642
  _RESOURCEQUOTASTATUS_USEDENTRY._serialized_end=40685
  _RESOURCEREQUIREMENTS._serialized_start=40688
  _RESOURCEREQUIREMENTS._serialized_end=41085
  _RESOURCEREQUIREMENTS_LIMITSENTRY._serialized_start=40991
  _RESOURCEREQUIREMENTS_LIMITSENTRY._serialized_end=41036
  _RESOURCEREQUIREMENTS_REQUESTSENTRY._serialized_start=41038
  _RESOURCEREQUIREMENTS_REQUESTSENTRY._serialized_end=41085
  _SELINUXOPTIONS._serialized_start=41088
  _SELINUXOPTIONS._serialized_end=41218
  _SCALEIOPERSISTENTVOLUMESOURCE._serialized_start=41221
  _SCALEIOPERSISTENTVOLUMESOURCE._serialized_end=41557
  _SCALEIOVOLUMESOURCE._serialized_start=41560
  _SCALEIOVOLUMESOURCE._serialized_end=41891
  _SCOPESELECTOR._serialized_start=41894
  _SCOPESELECTOR._serialized_end=42057
  _SCOPEDRESOURCESELECTORREQUIREMENT._serialized_start=42060
  _SCOPEDRESOURCESELECTORREQUIREMENT._serialized_end=42206
  _SECCOMPPROFILE._serialized_start=42208
  _SECCOMPPROFILE._serialized_end=42322
  _SECRET._serialized_start=42325
  _SECRET._serialized_end=42766
  _SECRET_DATAENTRY._serialized_start=4981
  _SECRET_DATAENTRY._serialized_end=5024
  _SECRET_STRINGDATAENTRY._serialized_start=42717
  _SECRET_STRINGDATAENTRY._serialized_end=42766
  _SECRETENVSOURCE._serialized_start=42768
  _SECRETENVSOURCE._serialized_end=42874
  _SECRETKEYSELECTOR._serialized_start=42876
  _SECRETKEYSELECTOR._serialized_end=42997
  _SECRETLIST._serialized_start=43000
  _SECRETLIST._serialized_end=43231
  _SECRETPROJECTION._serialized_start=43234
  _SECRETPROJECTION._serialized_end=43396
  _SECRETREFERENCE._serialized_start=43398
  _SECRETREFERENCE._serialized_end=43505
  _SECRETVOLUMESOURCE._serialized_start=43508
  _SECRETVOLUMESOURCE._serialized_end=43701
  _SECURITYCONTEXT._serialized_start=43704
  _SECURITYCONTEXT._serialized_end=44248
  _SERVICE._serialized_start=44251
  _SERVICE._serialized_end=44545
  _SERVICEACCOUNT._serialized_start=44548
  _SERVICEACCOUNT._serialized_end=44916
  _SERVICEACCOUNTLIST._serialized_start=44919
  _SERVICEACCOUNTLIST._serialized_end=45166
  _SERVICEACCOUNTTOKENPROJECTION._serialized_start=45169
  _SERVICEACCOUNTTOKENPROJECTION._serialized_end=45317
  _SERVICELIST._serialized_start=45320
  _SERVICELIST._serialized_end=45553
  _SERVICEPORT._serialized_start=45556
  _SERVICEPORT._serialized_end=45793
  _SERVICESPEC._serialized_start=45796
  _SERVICESPEC._serialized_end=46574
  _SERVICESPEC_SELECTORENTRY._serialized_start=38888
  _SERVICESPEC_SELECTORENTRY._serialized_end=38935
  _SERVICESTATUS._serialized_start=46577
  _SERVICESTATUS._serialized_end=46799
  _SESSIONAFFINITYCONFIG._serialized_start=46802
  _SESSIONAFFINITYCONFIG._serialized_end=46946
  _STORAGEOSPERSISTENTVOLUMESOURCE._serialized_start=46949
  _STORAGEOSPERSISTENTVOLUMESOURCE._serialized_end=47188
  _STORAGEOSVOLUMESOURCE._serialized_start=47191
  _STORAGEOSVOLUMESOURCE._serialized_end=47425
  _SYSCTL._serialized_start=47427
  _SYSCTL._serialized_end=47521
  _TCPSOCKETACTION._serialized_start=47524
  _TCPSOCKETACTION._serialized_end=47685
  _TAINT._serialized_start=47688
  _TAINT._serialized_end=47869
  _TOLERATION._serialized_start=47872
  _TOLERATION._serialized_end=48031
  _TOPOLOGYSELECTORLABELREQUIREMENT._serialized_start=48033
  _TOPOLOGYSELECTORLABELREQUIREMENT._serialized_end=48153
  _TOPOLOGYSELECTORTERM._serialized_start=48156
  _TOPOLOGYSELECTORTERM._serialized_end=48331
  _TOPOLOGYSPREADCONSTRAINT._serialized_start=48334
  _TOPOLOGYSPREADCONSTRAINT._serialized_end=48676
  _TYPEDLOCALOBJECTREFERENCE._serialized_start=48679
  _TYPEDLOCALOBJECTREFERENCE._serialized_end=48810
  _TYPEDOBJECTREFERENCE._serialized_start=48813
  _TYPEDOBJECTREFERENCE._serialized_end=48958
  _VOLUME._serialized_start=48961
  _VOLUME._serialized_end=51126
  _VOLUMEDEVICE._serialized_start=51128
  _VOLUMEDEVICE._serialized_end=51234
  _VOLUMEMOUNT._serialized_start=51237
  _VOLUMEMOUNT._serialized_end=51428
  _VOLUMENODEAFFINITY._serialized_start=51431
  _VOLUMENODEAFFINITY._serialized_end=51569
  _VOLUMEPROJECTION._serialized_start=51572
  _VOLUMEPROJECTION._serialized_end=51947
  _VSPHEREVIRTUALDISKVOLUMESOURCE._serialized_start=51950
  _VSPHEREVIRTUALDISKVOLUMESOURCE._serialized_end=52133
  _WEIGHTEDPODAFFINITYTERM._serialized_start=52136
  _WEIGHTEDPODAFFINITYTERM._serialized_end=52307
  _WINDOWSSECURITYCONTEXTOPTIONS._serialized_start=52310
  _WINDOWSSECURITYCONTEXTOPTIONS._serialized_end=52511
# @@protoc_insertion_point(module_scope)
